-- ============================================================================
-- Project:	ddbench - Deductive System and Database Benchmarks
-- Filename:	db/bam.sql
-- Purpose:	Database for Benchmark Runs: Data for our BAM implementation
-- Last Change:	03.03.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- System to be Tested/Compared:
-- ============================================================================

-- INSERT INTO TEST_SYS VALUES (
--	SYS, SEQ_NO, FULL_NAME, STYPE,
--	URL,
--	REMARK);

INSERT INTO TEST_SYS VALUES (
	'bam', 21, 'Push (bam)', 'Datalog',
	'http://users.informatik.uni-halle.de/~brass/push/',
	NULL);


-- ============================================================================
-- Versions of the Test System:
-- ============================================================================

-- INSERT INTO SYS_VER VALUES (
--	SYS, VER, VER_ADDTEXT, VER_DATE,
--	REMARK);

INSERT INTO SYS_VER VALUES (
	'bam', '0.1a', '', '2018-04-24',
	NULL);

INSERT INTO SYS_VER VALUES (
	'bam', '0.1b', '', '2019-02-27',
	'After replacing fixed-size stack with dynamic stack');

-- ============================================================================
-- Installed Program Versions on Machines:
-- ============================================================================

-- INSERT INTO SYS_INSTALL VALUES (
-- 	SYS, VER, MACHINE, INST_NO,
-- 	COMPILER,
-- 	STATUS, -- 'C': current version, 'P' previous, 'A' alternate, ' ' other
-- 	REMARK);

-- Installations on main test machine:

INSERT INTO SYS_INSTALL VALUES (
	'bam', '0.1a', 'dbs1', 1,
	'gcc version 4.9.2 (-O2)',
	'P',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'bam', '0.1b', 'dbs1', 2,
	'gcc version 4.9.2 (-O3)',
	'C',
	NULL);

-- Installations on development machine:

INSERT INTO SYS_INSTALL VALUES (
	'bam', '0.1a', 'bach', 1,
	'gcc version 4.8.5 (-O2)',
	'C',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'bam', '0.1b', 'bach', 2,
	'gcc version 4.8.5 (-O3)',
	'C',
	NULL);

-- Installations on old test machine:

INSERT INTO SYS_INSTALL VALUES (
	'bam', '0.1a', 'dbs0', 1,
	'gcc version 4.9.2 (-O2)',
	'C',
	NULL);


-- ============================================================================
-- Benchmark Implementations:
-- ============================================================================

-- INSERT INTO BENCH_IMPL VALUES (
-- 	SYS, BENCH, IMPL, STATUS, -- STATUS='B': best, 'A' alternate, ' ' other
-- 	DESCRIPTION);

-- ----------------------------------------------------------------------------
-- DBLP Benchmark:
-- ----------------------------------------------------------------------------


-- ----------------------------------------------------------------------------
-- Join1 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '1', ' ',
	'Join1, a(X,Y) [V1: RelAttr, -goto, fullDupCh]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '2', ' ',
	'Join1, a(X,Y) [V2: no goto, bitmap-dupcheck]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '3', 'B',
	'Join1, a(X,Y) [V3: goto, bitmap-dupC, cursor]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '4', 'A',
	'Join1, a(X,Y) [V4: functions, bitmap-dupC]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '5', ' ',
	'Join1, a(X,Y) [V5: fun without args, bitmap]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '6', 'A',
	'Join1, a(X,Y) [V6: Abstract Machine, bitmap]');

-- ----------------------------------------------------------------------------
-- TCFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '1', ' ',
	'tc(X,Y) [V1: RelLocalVar]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '2', 'A',
	'tc(X,Y) [V2: Cursor Interface, switch]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '3', 'A',
	'tc(X,Y) [V3: Seminaive Evaluation]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '4', 'A',
	'tc(X,Y) [V4: Functions]');

	-- Not really best, but this is the BAM:
INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '5', 'B',
	'tc(X,Y) [V5: Abstract Machine]');

-- ----------------------------------------------------------------------------
-- TCBF Benchmark:
-- ----------------------------------------------------------------------------


-- ----------------------------------------------------------------------------
-- TCFB Benchmark:
-- ----------------------------------------------------------------------------


-- ----------------------------------------------------------------------------
-- SGFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'sgff', '1', 'A',
	'tc(X,Y) [V1: Push Functions]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'sgff', '2', 'B',
	'tc(X,Y) [V2: Abstract Machine]');


-- ----------------------------------------------------------------------------
-- Wine Ontology Benchmark:
-- ----------------------------------------------------------------------------


-- ----------------------------------------------------------------------------
-- Data Loader Tests:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'loadt', '1', 'A',
	'transitive closure data file (with handcrafted loader)');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'loadt', '2', 'B',
	'transitive closure data file (with general loader)');

-- ----------------------------------------------------------------------------
-- Set Implementation Tests (One Column):
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'set1', 'e', 'B',
	'Set with 1 column, extendible Hash table');

-- ----------------------------------------------------------------------------
-- Set Implementation Tests (Two Columns):
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'set2', 'e', 'B',
	'Set with 2 columns, extendible Hash table');

