-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/bench_cost.sql
-- Purpose:	Database for Benchmark Runs: Cost Measure Data for Benchmarks
-- Last Change:	10.10.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- Cost Measures for Benchmarks (for Analysis of Runtimes):
-- ============================================================================

-- CREATE TABLE BENCH_COST (
--	BENCH          VARCHAR(20) NOT NULL,
--	FILE_ID        VARCHAR(10) NOT NULL,
--	SIZE           NUMERIC(12) NOT NULL,
--	ITER           NUMERIC(12) NOT NULL,
--	INST           NUMERIC(12) NOT NULL,
--	CONSTRAINT BENCH_COST_PK
--		PRIMARY KEY(BENCH, FILE_ID),
--	CONSTRAINT BENCH_COST_REF_BENCHMARK
--		FOREIGN KEY (BENCH) REFERENCES BENCHMARK,
--	CONSTRAINT BENCH_COST_REF_INPUT_FILE
--		FOREIGN KEY(FILE_ID) REFERENCES INPUT_FILE,
--	CONSTRAINT BENCH_COST_SIZE_NONNEGATIVE
--		CHECK(SIZE >= 0),
--	CONSTRAINT BENCH_COST_ITER_NONNEGATIVE
--		CHECK(ITER >= 0),
--	CONSTRAINT BENCH_COST_INST_NONNEGATIVE
--		CHECK(INST >= 0));
--
-- SIZE is the number of derived tuples of the benchmark (result size).
-- INST is the number of applicable rule instances in the benchmark program.
-- This is also the number of rule instances that semi-naive evaluation would
-- consider.
-- ITER is the number of iterations that the T_P operator needs to compute
-- the entire minimal model (counting only iterations that derive new tuples).
-- The application of the non-recursive rules is the first iteration
-- (if they derive at least one tuple, otherwise it does not count as an
-- iteration).


-- ============================================================================
-- INSERT Statements for Input Graph Data:
-- ============================================================================

INSERT INTO BENCH_COST VALUES('tcff','k50',2500,1,127500);
INSERT INTO BENCH_COST VALUES('tcff','k100',10000,1,1010000);
INSERT INTO BENCH_COST VALUES('tcff','k500',250000,1,125250000);
INSERT INTO BENCH_COST VALUES('tcff','k1k',1000000,1,1001000000);
INSERT INTO BENCH_COST VALUES('tcff','k2k',4000000,1,8004000000);
INSERT INTO BENCH_COST VALUES('tcff','t50',1225,1,20825);
INSERT INTO BENCH_COST VALUES('tcff','t100',4950,1,166650);
INSERT INTO BENCH_COST VALUES('tcff','t500',124750,1,20833250);
INSERT INTO BENCH_COST VALUES('tcff','t1k',499500,1,166666500);
INSERT INTO BENCH_COST VALUES('tcff','t2k',1999000,1,1333333000);
INSERT INTO BENCH_COST VALUES('tcff','c1k',1000000,1000,1001000);
INSERT INTO BENCH_COST VALUES('tcff','c2k',4000000,2000,4002000);
INSERT INTO BENCH_COST VALUES('tcff','c3k',9000000,3000,9003000);
INSERT INTO BENCH_COST VALUES('tcff','c4k',16000000,4000,16004000);
INSERT INTO BENCH_COST VALUES('tcff','s1k_1',1000000,500,2002000);
INSERT INTO BENCH_COST VALUES('tcff','s1k_2',1000000,201,3003000);
INSERT INTO BENCH_COST VALUES('tcff','s1k_3',1000000,250,4004000);
INSERT INTO BENCH_COST VALUES('tcff','s1k_4',1000000,200,5005000);
INSERT INTO BENCH_COST VALUES('tcff','s1k_5',1000000,42,6006000);
INSERT INTO BENCH_COST VALUES('tcff','s2k_1',4000000,1000,8004000);
INSERT INTO BENCH_COST VALUES('tcff','s2k_2',4000000,288,12006000);
INSERT INTO BENCH_COST VALUES('tcff','s2k_3',4000000,500,16008000);
INSERT INTO BENCH_COST VALUES('tcff','s2k_4',4000000,400,20010000);
INSERT INTO BENCH_COST VALUES('tcff','s2k_5',4000000,127,24012000);
INSERT INTO BENCH_COST VALUES('tcff','p1k',499500,999,499500);
INSERT INTO BENCH_COST VALUES('tcff','p2k',1999000,1999,1999000);
INSERT INTO BENCH_COST VALUES('tcff','p3k',4498500,2999,4498500);
INSERT INTO BENCH_COST VALUES('tcff','p4k',7998000,3999,7998000);
INSERT INTO BENCH_COST VALUES('tcff','m4_2ki',12288,3,12288);
INSERT INTO BENCH_COST VALUES('tcff','m16_512',61440,15,61440);
INSERT INTO BENCH_COST VALUES('tcff','m64_128',258048,63,258048);
INSERT INTO BENCH_COST VALUES('tcff','m256_32',1044480,255,1044480);
INSERT INTO BENCH_COST VALUES('tcff','m1ki_8',4190208,1023,4190208);
INSERT INTO BENCH_COST VALUES('tcff','m4ki_2',16773120,4095,16773120);
INSERT INTO BENCH_COST VALUES('tcff','b17',1966082,16,1966082);
INSERT INTO BENCH_COST VALUES('tcff','b18',4194306,17,4194306);
INSERT INTO BENCH_COST VALUES('tcff','b19',8912898,18,8912898);
INSERT INTO BENCH_COST VALUES('tcff','v10',8194,9,8194);
INSERT INTO BENCH_COST VALUES('tcff','v11',18434,10,18434);
INSERT INTO BENCH_COST VALUES('tcff','v12',40962,11,40962);
INSERT INTO BENCH_COST VALUES('tcff','v17',1966082,16,1966082);
INSERT INTO BENCH_COST VALUES('tcff','v18',4194306,17,4194306);
INSERT INTO BENCH_COST VALUES('tcff','v19',8912898,18,8912898);
INSERT INTO BENCH_COST VALUES('tcff','y500_4k',9998000,4000,9998000);
INSERT INTO BENCH_COST VALUES('tcff','y500_8k',35996000,8000,35996000);
INSERT INTO BENCH_COST VALUES('tcff','y1k_4k',11998000,4000,11998000);
INSERT INTO BENCH_COST VALUES('tcff','y1k_8k',39996000,8000,39996000);
INSERT INTO BENCH_COST VALUES('tcff','u1k_50k',1000000,3,50050000);
INSERT INTO BENCH_COST VALUES('tcff','u1k_125k',1000000,2,125125000);
INSERT INTO BENCH_COST VALUES('tcff','u1k_250k',1000000,2,250250000);
INSERT INTO BENCH_COST VALUES('tcff','u2k_200k',4000000,3,400200000);
INSERT INTO BENCH_COST VALUES('tcff','u2k_500k',4000000,2,1000500000);
INSERT INTO BENCH_COST VALUES('tcff','u2k_1m',4000000,2,2001000000);
INSERT INTO BENCH_COST VALUES('tcff','a1k_50k',471621,8,15269270);
INSERT INTO BENCH_COST VALUES('tcff','a1k_125k',492680,5,40853746);
INSERT INTO BENCH_COST VALUES('tcff','a1k_250k',497763,4,82941061);
INSERT INTO BENCH_COST VALUES('tcff','a2k_200k',1944729,8,128420988);
INSERT INTO BENCH_COST VALUES('tcff','a2k_500k',1985321,6,330666855);
INSERT INTO BENCH_COST VALUES('tcff','a2k_1m',1995698,4,666033613);
INSERT INTO BENCH_COST VALUES('tcff','w1k_1k',1000000,1,1000000);
INSERT INTO BENCH_COST VALUES('tcff','x10k',100020000,2,100020000);

INSERT INTO BENCH_COST VALUES('sgff','k50',2500,2,6252500);
INSERT INTO BENCH_COST VALUES('sgff','k100',10000,2,100010000);
INSERT INTO BENCH_COST VALUES('sgff','k500',250000,2,62500250000);
INSERT INTO BENCH_COST VALUES('sgff','k1k',1000000,2,1000001000000);
INSERT INTO BENCH_COST VALUES('sgff','k2k',4000000,2,16000004000000);
INSERT INTO BENCH_COST VALUES('sgff','t50',2402,2,1386602);
INSERT INTO BENCH_COST VALUES('sgff','t100',9802,2,23546952);
INSERT INTO BENCH_COST VALUES('sgff','t500',249002,2,15438684752);
INSERT INTO BENCH_COST VALUES('sgff','t1k',998002,2,248504744502);
INSERT INTO BENCH_COST VALUES('sgff','t2k',3996002,2,3988018989002);
INSERT INTO BENCH_COST VALUES('sgff','c1k',1000,1,2000);
INSERT INTO BENCH_COST VALUES('sgff','c2k',2000,1,4000);
INSERT INTO BENCH_COST VALUES('sgff','c3k',3000,1,6000);
INSERT INTO BENCH_COST VALUES('sgff','c4k',4000,1,8000);
INSERT INTO BENCH_COST VALUES('sgff','s1k_1',1000000,501,4002000);
INSERT INTO BENCH_COST VALUES('sgff','s1k_4',1000000,101,25005000);
INSERT INTO BENCH_COST VALUES('sgff','s2k_1',4000000,1001,16004000);
INSERT INTO BENCH_COST VALUES('sgff','s2k_3',4000000,251,64008000);
INSERT INTO BENCH_COST VALUES('sgff','s2k_4',4000000,201,100010000);
INSERT INTO BENCH_COST VALUES('sgff','p1k',1000,2,1998);
INSERT INTO BENCH_COST VALUES('sgff','p2k',2000,2,3998);
INSERT INTO BENCH_COST VALUES('sgff','p3k',3000,2,5998);
INSERT INTO BENCH_COST VALUES('sgff','p4k',4000,2,7998);
INSERT INTO BENCH_COST VALUES('sgff','m4_2ki',8192,2,12288);
INSERT INTO BENCH_COST VALUES('sgff','m16_512',8192,2,15360);
INSERT INTO BENCH_COST VALUES('sgff','m64_128',8192,2,16128);
INSERT INTO BENCH_COST VALUES('sgff','m256_32',8192,2,16320);
INSERT INTO BENCH_COST VALUES('sgff','m1ki_8',8192,2,16368);
INSERT INTO BENCH_COST VALUES('sgff','m4ki_2',8192,2,16380);
INSERT INTO BENCH_COST VALUES('sgff','b17',131071,2,262140);
INSERT INTO BENCH_COST VALUES('sgff','b18',262143,2,524284);
INSERT INTO BENCH_COST VALUES('sgff','b19',524287,2,1048572);
INSERT INTO BENCH_COST VALUES('sgff','v10',349525,9,350546);
INSERT INTO BENCH_COST VALUES('sgff','v11',1398101,10,1400146);
INSERT INTO BENCH_COST VALUES('sgff','v12',5592405,11,5596498);
INSERT INTO BENCH_COST VALUES('sgff','v17',5726623061,16,5726754130);
INSERT INTO BENCH_COST VALUES('sgff','v18',22906492245,17,22906754386);
INSERT INTO BENCH_COST VALUES('sgff','v19',91625968981,18,91626493266);
INSERT INTO BENCH_COST VALUES('sgff','y500_4k',254000,2,258498);
INSERT INTO BENCH_COST VALUES('sgff','y500_8k',258000,2,266498);
INSERT INTO BENCH_COST VALUES('sgff','y1k_4k',1004000,2,1008998);
INSERT INTO BENCH_COST VALUES('sgff','y1k_8k',1008000,2,1016998);

INSERT INTO BENCH_COST VALUES('path2','k50',2500,1,125000);
INSERT INTO BENCH_COST VALUES('path2','k100',10000,1,1000000);
INSERT INTO BENCH_COST VALUES('path2','k500',250000,1,125000000);
INSERT INTO BENCH_COST VALUES('path2','k1k',1000000,1,1000000000);
INSERT INTO BENCH_COST VALUES('path2','k2k',4000000,1,8000000000);
INSERT INTO BENCH_COST VALUES('path2','t50',1176,1,19600);
INSERT INTO BENCH_COST VALUES('path2','t100',4851,1,161700);
INSERT INTO BENCH_COST VALUES('path2','t500',124251,1,20708500);
INSERT INTO BENCH_COST VALUES('path2','t1k',498501,1,166167000);
INSERT INTO BENCH_COST VALUES('path2','t2k',1997001,1,1331334000);
INSERT INTO BENCH_COST VALUES('path2','c1k',1000,1,1000);
INSERT INTO BENCH_COST VALUES('path2','c2k',2000,1,2000);
INSERT INTO BENCH_COST VALUES('path2','c3k',3000,1,3000);
INSERT INTO BENCH_COST VALUES('path2','c4k',4000,1,4000);
INSERT INTO BENCH_COST VALUES('path2','s1k_1',2002,1,3998);
INSERT INTO BENCH_COST VALUES('path2','s1k_4',5005,1,24970);
INSERT INTO BENCH_COST VALUES('path2','s2k_1',4002,1,7998);
INSERT INTO BENCH_COST VALUES('path2','s2k_3',8004,1,31988);
INSERT INTO BENCH_COST VALUES('path2','s2k_4',10005,1,49980);
INSERT INTO BENCH_COST VALUES('path2','p1k',998,1,998);
INSERT INTO BENCH_COST VALUES('path2','p2k',1998,1,1998);
INSERT INTO BENCH_COST VALUES('path2','p3k',2998,1,2998);
INSERT INTO BENCH_COST VALUES('path2','p4k',3998,1,3998);
INSERT INTO BENCH_COST VALUES('path2','m4_2ki',8184,1,8184);
INSERT INTO BENCH_COST VALUES('path2','m16_512',8160,1,8160);
INSERT INTO BENCH_COST VALUES('path2','m64_128',8064,1,8064);
INSERT INTO BENCH_COST VALUES('path2','m256_32',7680,1,7680);
INSERT INTO BENCH_COST VALUES('path2','m1ki_8',6144,1,6144);
INSERT INTO BENCH_COST VALUES('path2','m4ki_2',0,1,0);
INSERT INTO BENCH_COST VALUES('path2','b17',131068,1,131068);
INSERT INTO BENCH_COST VALUES('path2','b18',262140,1,262140);
INSERT INTO BENCH_COST VALUES('path2','b19',524284,1,524284);
INSERT INTO BENCH_COST VALUES('path2','v10',1020,1,1020);
INSERT INTO BENCH_COST VALUES('path2','v11',2044,1,2044);
INSERT INTO BENCH_COST VALUES('path2','v12',4092,1,4092);
INSERT INTO BENCH_COST VALUES('path2','v17',131068,1,131068);
INSERT INTO BENCH_COST VALUES('path2','v18',262140,1,262140);
INSERT INTO BENCH_COST VALUES('path2','v19',524284,1,524284);
INSERT INTO BENCH_COST VALUES('path2','y500_4k',4498,1,4498);
INSERT INTO BENCH_COST VALUES('path2','y500_8k',8498,1,8498);
INSERT INTO BENCH_COST VALUES('path2','y1k_4k',4998,1,4998);
INSERT INTO BENCH_COST VALUES('path2','y1k_8k',8998,1,8998);

INSERT INTO BENCH_COST VALUES('j1axy','j1k10k',1825612,1,61988581);
INSERT INTO BENCH_COST VALUES('j1axy','j1k50k',3856026,1,981332692);
INSERT INTO BENCH_COST VALUES('j1axy','j1k250k',4000000,1,1375000127);

-- ============================================================================
-- Automatically Added Benchmark Cost Data:
-- ============================================================================

-- DO NOT DELETE THIS MARK
