-- ============================================================================
-- Project:	ddbench - Deductive System and Database Benchmarks
-- Filename:	db/benchmarks.sql
-- Purpose:	Database for Benchmark Runs: List of Benchmarks
-- Last Change:	04.10.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- List of Benchmarks:
-- ============================================================================

-- CREATE TABLE BENCHMARK(
-- 	BENCH      VARCHAR(20)  NOT NULL,
-- 	SEQ_NO     NUMERIC(2)   NOT NULL,
-- 	ITYPE      VARCHAR(8)   NULL,
-- 	HEADLINE   VARCHAR(80)  NOT NULL,
-- 	CONSTRAINT BENCHMARK_SEQ_NONNEGATIVE
-- 		CHECK(SEQ_NO >= 0),
-- 	CONSTRAINT BENCHMARK_PK
-- 		PRIMARY KEY (BENCH),
-- 	CONSTRAINT BENCHMARK_KEY_SEQ
-- 		UNIQUE (SEQ_NO),
-- 	CONSTRAINT BENCHMARK_REF_INPUT_TYPE
-- 		FOREIGN KEY (ITYPE) REFERENCES INPUT_TYPE);

-- INSERT INTO BENCHMARK VALUES (
--	BENCH, SEQ_NO, ITYPE->INPUT_TYPE,
--	HEADLINE);


INSERT INTO BENCHMARK VALUES (
	'tcff',    1, 'tc',
	'Transitive Closure Benchmark without Query Bindings');

INSERT INTO BENCHMARK VALUES (
	'tcbf',    2, 'tc',
	'Transitive Closure Benchmark with the First Argument Bound');

INSERT INTO BENCHMARK VALUES (
	'tcbfs',   3, 'tc',
	'Transitive Closure Benchmark, First Argument Bound, with SLDMagic');

INSERT INTO BENCHMARK VALUES (
	'tcfb',    4, 'tc',
	'Transitive Closure Benchmark with the Second Argument Bound');

INSERT INTO BENCHMARK VALUES (
	'path2',   5, 'tc',
	'Path consisting of two edges');

INSERT INTO BENCHMARK VALUES (
	'path3F',  6, 'tc',
	'Path consisting of three edges (flat version: join of all three)');

INSERT INTO BENCHMARK VALUES (
	'path3L',  7, 'tc',
	'Path consisting of three edges (left nested join)');

INSERT INTO BENCHMARK VALUES (
	'path3R',  8, 'tc',
	'Path consisting of three edges (right nested join)');

INSERT INTO BENCHMARK VALUES (
	'sgff',    9, 'tc',
	'Same Generation Benchmark without Query Bindings');

INSERT INTO BENCHMARK VALUES (
	'sgbf',   10, 'tc',
	'Same Generation Benchmark with First Argument Bound');

INSERT INTO BENCHMARK VALUES (
	'sgfb',   11, 'tc',
	'Same Generation Benchmark with Second Argument Bound');

INSERT INTO BENCHMARK VALUES (
	'j1axy',  12, 'j1',
	'The Join1 Benchmark, Query a(X,Y)');

INSERT INTO BENCHMARK VALUES (
	'j1axyd', 13, 'j1',
	'The Join1 Benchmark (without duplicate elimination)');

INSERT INTO BENCHMARK VALUES (
	'dblp',   14, 'dblp',
	'DBLP Benchmark');

INSERT INTO BENCHMARK VALUES (
	'wine',   15, 'wine',
	'Wine Ontology Benchmark');

INSERT INTO BENCHMARK VALUES (
	'win',    16, 'tc',
	'win WFS Benchmark');

INSERT INTO BENCHMARK VALUES (
	'loadd',  17, 'dblp',
	'Test of Loader for DBLP Data');

INSERT INTO BENCHMARK VALUES (
	'loadt',  18, 'tc',
	'Test of Loader for Transitive Closure');

INSERT INTO BENCHMARK VALUES (
	'set1',   19, NULL,
	'Test of Set Insertion and Lookup (One Column)');

INSERT INTO BENCHMARK VALUES (
	'set2',   20, NULL,
	'Test of Set Insertion and Lookup (Two Columns)');

