-- ============================================================================
-- Project:	ddbench - Logic Programming and Database Benchmarks
-- Filename:	db/drop_db.sql
-- Purpose:	Database for Benchmark Runs: Drop all Tables and Views
-- Last Change:	11.10.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2018-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ############################################################################
-- Delete Old Versions of Tables and Views:
-- ############################################################################

-- When this script is executed the first time,
-- these commands generate errors (because the tables/views do not exist).

-- Note that the DROP commands are in opposite order of the CREATE commands
-- so that there are no error messages for dangling references.
-- E.g. if table A contains a foreign key pointing to table B,
-- table A must be dropped before table B.
-- Also if view A is used in view B, view B must be dropped before A.


-- ============================================================================
-- Views to Support Benchmark Execution Scripts (File v_scripts.sql):
-- ============================================================================

DROP VIEW TC_FILE_IDS;
DROP VIEW BENCH_FILE_LIST;

-- ============================================================================
-- Views to Print Table Data in Markdown Format for Docs (File v_doc.sql):
-- ============================================================================

DROP VIEW BENCH_COST_MD;
DROP VIEW INPUT_GRAPH_MD;
DROP VIEW INPUT_FILE_MD;
DROP VIEW BENCH_IMPL_MD;

-- ============================================================================
-- Views to Support Research on Runtime Estimation (File v_estimate.sql):
-- ============================================================================

DROP VIEW  PAR_RANGE;
DROP VIEW  LOAD_EFFICIENCY;
DROP VIEW  ESTIMATE_DATA_CSV;
DROP VIEW  ESTIMATE_DATA;

DROP VIEW  EVAL_ESTIMATES;
DROP VIEW  NUM_GOOD_ESTIMATES;
DROP VIEW  NUM_BAD_ESTIMATES;
DROP VIEW  ESTIMATE_ERR;
DROP VIEW  ESTIMATE_FORMULA;
DROP VIEW  SPEED_REAL;
DROP VIEW  SPEED_REAL_DIFF;
DROP VIEW  SPEED_CPU;
DROP VIEW  MEM_EFFICIENCY;

-- ============================================================================
-- Views for Printing Graph Data in Various Formats (File v_graph.sql):
-- ============================================================================

DROP VIEW  INPUT_GRAPH_HTML;
DROP VIEW  INPUT_GRAPH_LATEX;

-- ============================================================================
-- Views for Analyzing Results of the Join1 a(X,Y) Benchmark (File v_j1axy.sql):
-- ============================================================================

DROP VIEW  J1AXY_PLOT_REAL;

DROP VIEW  INPUT_JOIN1_HTML;

DROP VIEW  J1AXY_REAL_XSB_HTML;
DROP VIEW  J1AXY_REAL_XSB_LATEX;
DROP VIEW  J1AXY_REAL_XSB_FACTORS;
DROP VIEW  J1AXY_REAL_XSB;

DROP VIEW  J1AXY_MEM;
DROP VIEW  J1AXY_REAL_CSV;
DROP VIEW  J1AXY_REAL_LATEX;
DROP VIEW  J1AXY_REAL_FACTORS;
DROP VIEW  J1AXY_REAL;
DROP VIEW  J1AXY_CPU_LATEX;
DROP VIEW  J1AXY_CPU;


-- ============================================================================
-- Views for Analyzing Results of the SGFF Benchmark (File v_sgff.sql):
-- ============================================================================

DROP VIEW  SGFF_CPU;

DROP VIEW  SGFF_REAL_CSV;

DROP VIEW  SGFF_REAL_LATEX;
DROP VIEW  SGFF_REAL_FACTORS;
DROP VIEW  SGFF_REAL;

DROP VIEW  SGFF_REAL_XSB_HTML;
DROP VIEW  SGFF_REAL_XSB_LATEX;
DROP VIEW  SGFF_REAL_XSB_AVG;
DROP VIEW  SGFF_REAL_XSB_FACTORS;
DROP VIEW  SGFF_REAL_XSB;

DROP VIEW  SGFF_MEM;
DROP VIEW  SGFF_CPU_LATEX;
DROP VIEW  SGFF_PLOT_MEM;
DROP VIEW  SGFF_PLOT_CPU;
DROP VIEW  SGFF_PLOT_REAL;

-- ============================================================================
-- Views for Analyzing Results of the TCFF Benchmark (File v_tcff.sql):
-- ============================================================================

DROP VIEW  TCFF_CPU;

DROP VIEW  TCFF_REAL_LATEX;
DROP VIEW  TCFF_REAL_FACTORS;
DROP VIEW  TCFF_REAL;

DROP VIEW  TCFF_REAL_XSB_HTML;
DROP VIEW  TCFF_REAL_XSB_LATEX;
DROP VIEW  TCFF_REAL_XSB_AVG;
DROP VIEW  TCFF_REAL_XSB_FACTORS;
DROP VIEW  TCFF_REAL_XSB;

DROP VIEW  TCFF_MEM;
DROP VIEW  TCFF_CPU_LATEX;
DROP VIEW  TCFF_PLOT_MEM;
DROP VIEW  TCFF_PLOT_CPU;
DROP VIEW  TCFF_PLOT_REAL;

-- ============================================================================
-- Views for Analyzing Data of Single Systems (e.g. File v_xsb.sql):
-- ============================================================================

DROP VIEW  XSB_TCFF_COMP;
DROP VIEW  XSB;

DROP VIEW  BAM;
DROP VIEW  YAP;
DROP VIEW  SQLITE;
DROP VIEW  PSQL;

DROP VIEW  MARIA_COMPARE;
DROP VIEW  MARIA;

DROP VIEW  SOUFFLE;
DROP VIEW  JENA;
DROP VIEW  NEO4J;
DROP VIEW  DATASCRIPT;

-- ============================================================================
-- Views for Detecting Outliers and other Data Checks (File v_check.sql):
-- ============================================================================

DROP VIEW  INTEGRITY_ERROR;
DROP VIEW  PCT_CPU;
DROP VIEW  PCT_CPU_INPUT;
DROP VIEW  REAL_TOO_LARGE;
DROP VIEW  OUTLIER_MEM;
DROP VIEW  OUTLIER_CPU;
DROP VIEW  OUTLIER_REAL;

-- ============================================================================
-- Basic Views for Computing Statistics (File v_basic.sql):
-- ============================================================================

DROP VIEW  BEST_IMPL_CPU;
DROP VIEW  BEST_IMPL_REAL;

DROP VIEW  BEST_RESULT;
DROP VIEW  RESULT CASCADE;
DROP VIEW  RUN_STATISTICS;
DROP VIEW  RUN_STAT;

DROP VIEW  OVERVIEW;

-- ============================================================================
-- Base Tables (File create_db.sql):
-- ============================================================================

DROP TABLE ESTIMATE_PAR;

DROP TABLE DUMMY_TAB;

DROP TABLE BENCH_RUN;
DROP TABLE BENCH_IMPL;
DROP TABLE BENCH_COST;
DROP TABLE INPUT_JOIN1;
DROP TABLE INPUT_GRAPH;
DROP TABLE GRAPH_TYPE;
DROP TABLE INPUT_SET;
DROP TABLE INPUT_FILE;
DROP TABLE SYS_INSTALL;
DROP TABLE SYS_VER;
DROP TABLE TEST_SYS;
DROP TABLE SYS_TYPE;
DROP TABLE BENCHMARK;
DROP TABLE INPUT_TYPE;
DROP TABLE MACHINE;

