-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/gen_html.sql
-- Purpose:	Compute tables for website from benchmark database
-- Last Change:	04.10.2018
-- Language:	psql script (SQL for PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Note:	There is no warranty at all - this code may contain bugs.
-- Copyright:	You can use this as you wish, but don't make me responsible!
--		I would be interested to hear about improved versions.
-- ============================================================================

-- This script can be called e.g. as follows:
--	psql -f gen_html.sql
-- Of course, the benchmark database defined in bench_db.sql must be available.

-- Note: The script also overwrites the files with the results, i.e.
--	tcff_real.html
--	sgff_real.html
--	j1axy_real.html
--	graph_data.html
--	join1_data.html

-- ----------------------------------------------------------------------------
\echo 'Set psql output format to pure data:'
-- ----------------------------------------------------------------------------

-- Tuples only:
\t on
-- Unaligned output (suppresses the mapping of "\n" to "+\n")
\pset format unaligned

-- ----------------------------------------------------------------------------
\echo 'Creating tcff_real_xsb.html:'
-- ----------------------------------------------------------------------------

-- Output file:
\o html/tcff_real_xsb.html

-- Generate TCFF Comparison:
select html from tcff_real_xsb_html;

-- ----------------------------------------------------------------------------
\echo 'Creating sgff_real_xsb.html:'
-- ----------------------------------------------------------------------------

-- Output file:
\o html/sgff_real_xsb.html

-- Generate SGFF Comparison:
select html from sgff_real_xsb_html;

-- ----------------------------------------------------------------------------
\echo 'Creating sgff_real.csv:'
-- ----------------------------------------------------------------------------

-- Output file:
\o html/sgff_real.csv

-- Generate SGFF Comparison:
select csv from sgff_real_csv;

-- ----------------------------------------------------------------------------
\echo 'Creating j1axy_real_xsb.html:'
-- ----------------------------------------------------------------------------

-- Output file:
\o html/j1axy_real_xsb.html

-- Generate SGFF Comparison:
select html from j1axy_real_xsb_html;

-- ----------------------------------------------------------------------------
\echo 'Creating j1axy_real.csv:'
-- ----------------------------------------------------------------------------

-- Output file:
\o html/j1axy_real.csv

-- Generate SGFF Comparison:
select csv from j1axy_real_csv;

-- ----------------------------------------------------------------------------
\echo 'Creating graph_data.html:'
-- ----------------------------------------------------------------------------

-- Output file:
\o html/graph_data.html

-- Generate Graph Data Table:
select html from input_graph_html;

-- ----------------------------------------------------------------------------
\echo 'Creating join1_data.html:'
-- ----------------------------------------------------------------------------

-- Output file:
\o html/join1_data.html

-- Generate Graph Data Table:
select html from input_join1_html;


-- ----------------------------------------------------------------------------
\echo 'Set psql output format back to normal:'
-- ----------------------------------------------------------------------------

-- Standard output again:
\o
-- Normal output again:
\pset format aligned
-- Normal decoration of tables:
\t off

-- ----------------------------------------------------------------------------
\echo 'Done.'
-- ----------------------------------------------------------------------------

