-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/gen_latex.sql
-- Purpose:	Compute latex table with runtimes from bench DB
-- Last Change:	30.04.2019
-- Language:	psql script (SQL for PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Note:	There is no warranty at all - this code may contain bugs.
-- Copyright:	You can use this as you wish, but don't make me responsible!
--		I would be interested to hear about improved versions.
-- ============================================================================

-- This script can be called e.g. as follows:
--	psql -f gen_latex.sql
-- Of course, the benchmark database defined in load_data must be available.

-- Note: The script overwrites the files with the results in the directory
--	latex


-- ============================================================================
\echo 'Changing output format to only data.'
-- ============================================================================

-- Tuples only:
\t on
-- Unaligned output (suppresses the mapping of "\n" to "+\n")
\pset format unaligned

-- ============================================================================
\echo 'Creating LaTeX Tables with TCFF Runtime Data.'
-- ============================================================================

-- Output file:
\o latex/tcff_real.tex
-- Generate TCFF Runtime Data (Real Time):
select latex from tcff_real_latex;

-- Output file:
\o latex/tcff_real_xsb.tex
-- Generate TCFF Data (Comparison with XSB):
select latex from tcff_real_xsb_latex;

-- Output file:
\o latex/tcff_cpu.tex
-- Generate TCFF Runtime Data (CPU Time):
select latex from tcff_cpu_latex;

-- Standard output again:
\o

-- ============================================================================
\echo 'Creating LaTeX Tables with SGFF Runtime Data.'
-- ============================================================================

-- Output file:
\o latex/sgff_real.tex
-- Generate SGFF Runtime Data (Real Time):
select latex from sgff_real_latex;

-- Output file:
\o latex/sgff_real_xsb.tex
-- Generate SGFF Data (Comparison with XSB):
select latex from sgff_real_xsb_latex;

-- Output file:
\o latex/sgff_cpu.tex
-- Generate SGFF Runtime Data (CPU Time):
select latex from sgff_cpu_latex;

-- Standard output again:
\o

-- ============================================================================
\echo 'Changing back to standard output format.'
-- ============================================================================

-- Normal output again:
\pset format aligned
-- Normal decoration of tables:
\t off

