-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/gen_plots.sql
-- Purpose:	Compute data files for plots in research paper from bench DB
-- Last Change:	05.03.2019
-- Language:	psql script (SQL for PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Note:	There is no warranty at all - this code may contain bugs.
-- Copyright:	You can use this as you wish, but don't make me responsible!
--		I would be interested to hear about improved versions.
-- ============================================================================

-- This script can be called e.g. as follows:
--	psql -f gen_plots.sql
-- Of course, the benchmark database defined in load_data must be available.

-- Note: The script overwrites the files with the results in the directory
--	plots_sgff
--	plots_j1axy


-- ============================================================================
\echo 'Changing output format to only data.'
-- ============================================================================

-- Tuples only:
\t on
-- Unaligned output (suppresses the mapping of "\n" to "+\n")
\pset format unaligned

-- ============================================================================
\echo 'Creating data files for TCFF plots in TSV format.'
-- ============================================================================

-- Output file:
\o plots_tcff/bam_cost.tsv
-- Generate TCFF Cost-Runtime Data for BAM:
select tsv from tcff_plot_real where sys='bam' and tsv is not null;

-- Output file:
\o plots_tcff/xsb_cost.tsv
-- Generate TCFF Cost-Runtime Data for XSB:
select tsv from tcff_plot_real where sys='xsb' and tsv is not null;

-- Output file:
\o plots_tcff/yap_cost.tsv
-- Generate TCFF Cost-Runtime Data for YAP:
select tsv from tcff_plot_real where sys='yap' and tsv is not null;

-- Output file:
\o plots_tcff/souffle_cost.tsv
-- Generate TCFF Cost-Runtime Data for Souffle:
select tsv from tcff_plot_real where sys='souffle' and tsv is not null;

-- Output file:
\o plots_tcff/sqlite_cost.tsv
-- Generate TCFF Cost-Runtime Data for SQLite:
select tsv from tcff_plot_real where sys='sqlite3' and tsv is not null;

-- Output file:
\o plots_tcff/psql_cost.tsv
-- Generate TCFF Cost-Runtime Data for PostgreSQL:
select tsv from tcff_plot_real where sys='psql' and tsv is not null;

-- Output file:
\o plots_tcff/maria_cost.tsv
-- Generate TCFF Cost-Runtime Data for MariaDB:
select tsv from tcff_plot_real where sys='mariadb' and tsv is not null;

-- Output file:
\o plots_tcff/jena_cost.tsv
-- Generate TCFF Cost-Runtime Data for Apache Jena:
select tsv from tcff_plot_real where sys='jena' and tsv is not null;

-- Standard output again:
\o

-- ============================================================================
\echo 'Creating data files for TCFF plots in CSV format.'
-- ============================================================================

-- Output file:
\o plots_tcff/bam_cost.csv
-- Generate TCFF Cost-Runtime Data for BAM:
select csv from tcff_plot_real where sys='bam' and csv is not null;

-- Output file:
\o plots_tcff/xsb_cost.csv
-- Generate TCFF Cost-Runtime Data for XSB:
select csv from tcff_plot_real where sys='xsb' and csv is not null;

-- Output file:
\o plots_tcff/yap_cost.csv
-- Generate TCFF Cost-Runtime Data for YAP:
select csv from tcff_plot_real where sys='yap' and csv is not null;

-- Output file:
\o plots_tcff/souffle_cost.csv
-- Generate TCFF Cost-Runtime Data for Souffle:
select csv from tcff_plot_real where sys='souffle' and csv is not null;

-- Output file:
\o plots_tcff/sqlite_cost.csv
-- Generate TCFF Cost-Runtime Data for SQLite:
select csv from tcff_plot_real where sys='sqlite3' and csv is not null;

-- Output file:
\o plots_tcff/psql_cost.csv
-- Generate TCFF Cost-Runtime Data for PostgreSQL:
select csv from tcff_plot_real where sys='psql' and csv is not null;

-- Output file:
\o plots_tcff/maria_cost.csv
-- Generate TCFF Cost-Runtime Data for MariaDB:
select csv from tcff_plot_real where sys='mariadb' and csv is not null;

-- Output file:
\o plots_tcff/jena_cost.csv
-- Generate TCFF Cost-Runtime Data for Apache Jena:
select csv from tcff_plot_real where sys='jena' and csv is not null;

-- Standard output again:
\o


-- ============================================================================
\echo 'Creating data files for SGFF plots in TSV format.'
-- ============================================================================

-- Output file:
\o plots_sgff/bam_cost.tsv
-- Generate SGFF Cost-Runtime Data for BAM:
select tsv from sgff_plot_real where sys='bam' and tsv is not null;

-- Output file:
\o plots_sgff/xsb_cost.tsv
-- Generate SGFF Cost-Runtime Data for XSB:
select tsv from sgff_plot_real where sys='xsb' and tsv is not null;

-- Output file:
\o plots_sgff/yap_cost.tsv
-- Generate SGFF Cost-Runtime Data for YAP:
select tsv from sgff_plot_real where sys='yap' and tsv is not null;

-- Output file:
\o plots_sgff/souffle_cost.tsv
-- Generate SGFF Cost-Runtime Data for Souffle:
select tsv from sgff_plot_real where sys='souffle' and tsv is not null;

-- Output file:
\o plots_sgff/sqlite_cost.tsv
-- Generate SGFF Cost-Runtime Data for SQLite:
select tsv from sgff_plot_real where sys='sqlite3' and tsv is not null;

-- Output file:
\o plots_sgff/psql_cost.tsv
-- Generate SGFF Cost-Runtime Data for PostgreSQL:
select tsv from sgff_plot_real where sys='psql' and tsv is not null;

-- Output file:
\o plots_sgff/maria_cost.tsv
-- Generate SGFF Cost-Runtime Data for MariaDB:
select tsv from sgff_plot_real where sys='mariadb' and tsv is not null;

-- Standard output again:
\o

-- ============================================================================
\echo 'Creating data files for SGFF plots in CSV format.'
-- ============================================================================

-- Output file:
\o plots_sgff/bam_cost.csv
-- Generate SGFF Cost-Runtime Data for BAM:
select csv from sgff_plot_real where sys='bam' and csv is not null;

-- Output file:
\o plots_sgff/xsb_cost.csv
-- Generate SGFF Cost-Runtime Data for XSB:
select csv from sgff_plot_real where sys='xsb' and csv is not null;

-- Output file:
\o plots_sgff/yap_cost.csv
-- Generate SGFF Cost-Runtime Data for YAP:
select csv from sgff_plot_real where sys='yap' and csv is not null;

-- Output file:
\o plots_sgff/souffle_cost.csv
-- Generate SGFF Cost-Runtime Data for Souffle:
select csv from sgff_plot_real where sys='souffle' and csv is not null;

-- Output file:
\o plots_sgff/sqlite_cost.csv
-- Generate SGFF Cost-Runtime Data for SQLite:
select csv from sgff_plot_real where sys='sqlite3' and csv is not null;

-- Output file:
\o plots_sgff/psql_cost.csv
-- Generate SGFF Cost-Runtime Data for PostgreSQL:
select csv from sgff_plot_real where sys='psql' and csv is not null;

-- Output file:
\o plots_sgff/maria_cost.csv
-- Generate SGFF Cost-Runtime Data for MariaDB:
select csv from sgff_plot_real where sys='mariadb' and csv is not null;

-- Standard output again:
\o

-- ============================================================================
\echo 'Creating data files for Join1 a(X,Y) plots in TSV format.'
-- ============================================================================

-- Output file:
\o plots_j1axy/bam_cost.tsv
-- Generate SGFF Cost-Runtime Data for BAM:
select tsv from j1axy_plot_real where sys='bam' and tsv is not null;

-- Output file:
\o plots_j1axy/xsb_cost.tsv
-- Generate SGFF Cost-Runtime Data for XSB:
select tsv from j1axy_plot_real where sys='xsb' and tsv is not null;

-- Output file:
\o plots_j1axy/yap_cost.tsv
-- Generate SGFF Cost-Runtime Data for YAP:
select tsv from j1axy_plot_real where sys='yap' and tsv is not null;

-- Output file:
\o plots_j1axy/souffle_cost.tsv
-- Generate SGFF Cost-Runtime Data for Souffle:
select tsv from j1axy_plot_real where sys='souffle' and tsv is not null;

-- Output file:
\o plots_j1axy/sqlite_cost.tsv
-- Generate SGFF Cost-Runtime Data for SQLite:
select tsv from j1axy_plot_real where sys='sqlite3' and tsv is not null;

-- Output file:
\o plots_j1axy/psql_cost.tsv
-- Generate SGFF Cost-Runtime Data for PostgreSQL:
select tsv from j1axy_plot_real where sys='psql' and tsv is not null;

-- Output file:
\o plots_j1axy/maria_cost.tsv
-- Generate SGFF Cost-Runtime Data for MariaDB:
select tsv from j1axy_plot_real where sys='mariadb' and tsv is not null;

-- Standard output again:
\o

-- ============================================================================
\echo 'Creating data files for Join1 a(X,Y) plots in CSV format.'
-- ============================================================================

-- Output file:
\o plots_j1axy/bam_cost.csv
-- Generate SGFF Cost-Runtime Data for BAM:
select csv from j1axy_plot_real where sys='bam' and csv is not null;

-- Output file:
\o plots_j1axy/xsb_cost.csv
-- Generate SGFF Cost-Runtime Data for XSB:
select csv from j1axy_plot_real where sys='xsb' and csv is not null;

-- Output file:
\o plots_j1axy/yap_cost.csv
-- Generate SGFF Cost-Runtime Data for YAP:
select csv from j1axy_plot_real where sys='yap' and csv is not null;

-- Output file:
\o plots_j1axy/souffle_cost.csv
-- Generate SGFF Cost-Runtime Data for Souffle:
select csv from j1axy_plot_real where sys='souffle' and csv is not null;

-- Output file:
\o plots_j1axy/sqlite_cost.csv
-- Generate SGFF Cost-Runtime Data for SQLite:
select csv from j1axy_plot_real where sys='sqlite3' and csv is not null;

-- Output file:
\o plots_j1axy/psql_cost.csv
-- Generate SGFF Cost-Runtime Data for PostgreSQL:
select csv from j1axy_plot_real where sys='psql' and csv is not null;

-- Output file:
\o plots_j1axy/maria_cost.csv
-- Generate SGFF Cost-Runtime Data for MariaDB:
select csv from j1axy_plot_real where sys='mariadb' and csv is not null;

-- Standard output again:
\o

-- ============================================================================
\echo 'Changing back to standard output format.'
-- ============================================================================

-- Normal output again:
\pset format aligned
-- Normal decoration of tables:
\t off

