-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/input_graphs.sql
-- Purpose:	Database for Benchmark Runs: Data of Input Graphs
-- Last Change:	04.10.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2018 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- More Data on Data Files That are Directed Graphs:
-- ============================================================================

-- CREATE TABLE INPUT_GRAPH (
--	FILE_ID        VARCHAR(10) NOT NULL,
--	GTYPE          CHAR(1)     NOT NULL,
--	PARAM_1        NUMERIC(12) NULL,
--	PARAM_2        NUMERIC(12) NULL,
--	PARAM_3        CHAR(1)     NULL,
--	NUM_NODES      NUMERIC(12) NOT NULL,
--	NUM_EDGES      NUMERIC(12) NOT NULL,
--	DUP_EDGES      NUMERIC(12) NOT NULL,
--	LOOPS          CHAR(1)     NOT NULL,
--	MIN_IN_DEGREE  NUMERIC(12) NOT NULL,
--	MAX_IN_DEGREE  NUMERIC(12) NOT NULL,
--	MIN_OUT_DEGREE NUMERIC(12) NOT NULL,
--	MAX_OUT_DEGREE NUMERIC(12) NOT NULL,
--	CYCLES         CHAR(1)     NOT NULL,
--	CONSTRAINT INPUT_GRAPH_PK
--		PRIMARY KEY(FILE_ID),
--	CONSTRAINT INPUT_GRAPH_REF_INPUT_FILE
--		FOREIGN KEY(FILE_ID) REFERENCES INPUT_FILE,
--	CONSTRAINT INPUT_GRAPH_REF_GRAPH_TYPE
--		FOREIGN KEY (GTYPE) REFERENCES GRAPH_TYPE,
--	CONSTRAINT INPUT_GRAPH_PARAM_1_NONNEGATIVE
--		CHECK(PARAM_1 >= 0),
--	CONSTRAINT INPUT_GRAPH_PARAM_2_NONNEGATIVE
--		CHECK(PARAM_2 >= 0),
--	CONSTRAINT INPUT_GRAPH_PARAM_3_VALID
--		CHECK(PARAM_3 IN ('I')),
--	CONSTRAINT INPUT_GRAPH_NUM_NODES_NONNEGATIVE
--		CHECK(NUM_NODES >= 0),
--	CONSTRAINT INPUT_GRAPH_NUM_EDGES_NONNEGATIVE
--		CHECK(NUM_EDGES >= 0),
--	CONSTRAINT INPUT_GRAPH_DUP_EDGES_NONNEGATIVE
--		CHECK(DUP_EDGES >= 0),
--	CONSTRAINT INPUT_GRAPH_LOOPS_YES_NO
--		CHECK(LOOPS  in ('Y','N')),
--	CONSTRAINT INPUT_GRAPH_MIN_IN_DEGREE_NONNEGATIVE
--		CHECK(MIN_IN_DEGREE >= 0),
--	CONSTRAINT INPUT_GRAPH_MAX_IN_DEGREE_NONNEGATIVE
--		CHECK(MAX_IN_DEGREE >= 0),
--	CONSTRAINT INPUT_GRAPH_MIN_OUT_DEGREE_NONNEGATIVE
--		CHECK(MIN_OUT_DEGREE >= 0),
--	CONSTRAINT INPUT_GRAPH_MAX_OUT_DEGREE_NONNEGATIVE
--		CHECK(MAX_OUT_DEGREE >= 0),
--	CONSTRAINT INPUT_GRAPH_CYCLES_YES_NO
--		CHECK(CYCLES IN ('Y','N'));


-- GTYPE, PARAM_1, PARAM_2, and PARAM_3 are the parameters for the
-- Data Generation Program (currently, PARAM_3 has the only possible value
-- 'I' for inverting the direction of the edges).

-- DUP_EDGES is the number of duplicate edges,
-- i.e. the number of node pairs (x,y) such that there are at least two edges
-- between these nodes.
-- Normally, it should be 0.
-- However, the OpenRuleBench graph generation program generates such
-- duplicate edges for acyclic graphs.
-- Therefore, our graph analysis checks the input files for this case.

-- LOOPS='Y' means that there are edges of the form (x,x).

-- ============================================================================
-- INSERT Statements for Input Graph Data:
-- ============================================================================


INSERT INTO INPUT_GRAPH VALUES('b17','B',17,NULL, NULL,
131071,131070,0,'N',0,1,0,2,'N');

INSERT INTO INPUT_GRAPH VALUES('b18','B',18,NULL, NULL,
262143,262142,0,'N',0,1,0,2,'N');

INSERT INTO INPUT_GRAPH VALUES('b19','B',19,NULL, NULL,
524287,524286,0,'N',0,1,0,2,'N');

INSERT INTO INPUT_GRAPH VALUES('v10','B',10,NULL,'I',
1023,1022,0,'N',0,1,0,2,'N');

INSERT INTO INPUT_GRAPH VALUES('v11','B',11,NULL,'I',
2047,2046,0,'N',0,1,0,2,'N');

INSERT INTO INPUT_GRAPH VALUES('v12','B',12,NULL,'I',
4095,4094,0,'N',0,1,0,2,'N');

INSERT INTO INPUT_GRAPH VALUES('v17','B',17,NULL,'I',
131071,131070,0,'N',0,1,0,2,'N');

INSERT INTO INPUT_GRAPH VALUES('v18','B',18,NULL,'I',
262143,262142,0,'N',0,1,0,2,'N');

INSERT INTO INPUT_GRAPH VALUES('v19','B',19,NULL,'I',
524287,524286,0,'N',0,1,0,2,'N');

INSERT INTO INPUT_GRAPH VALUES('c1k','C',1000,NULL, NULL,
1000,1000,0,'N',1,1,1,1,'Y');

INSERT INTO INPUT_GRAPH VALUES('c2k','C',2000,NULL, NULL,
2000,2000,0,'N',1,1,1,1,'Y');

INSERT INTO INPUT_GRAPH VALUES('c3k','C',3000,NULL, NULL,
3000,3000,0,'N',1,1,1,1,'Y');

INSERT INTO INPUT_GRAPH VALUES('c4k','C',4000,NULL, NULL,
4000,4000,0,'N',1,1,1,1,'Y');

INSERT INTO INPUT_GRAPH VALUES('k50','K',50,NULL, NULL,
50,2500,0,'Y',50,50,50,50,'Y');

INSERT INTO INPUT_GRAPH VALUES('k100','K',100,NULL, NULL,
100,10000,0,'Y',100,100,100,100,'Y');

INSERT INTO INPUT_GRAPH VALUES('k500','K',500,NULL, NULL,
500,250000,0,'Y',500,500,500,500,'Y');

INSERT INTO INPUT_GRAPH VALUES('k1k','K',1000,NULL, NULL,
1000,1000000,0,'Y',1000,1000,1000,1000,'Y');

INSERT INTO INPUT_GRAPH VALUES('k2k','K',2000,NULL, NULL,
2000,4000000,0,'Y',2000,2000,2000,2000,'Y');

INSERT INTO INPUT_GRAPH VALUES('t50','T',50,NULL, NULL,
50,1225,0,'N',0,49,0,49,'N');

INSERT INTO INPUT_GRAPH VALUES('t100','T',100,NULL, NULL,
100,4950,0,'N',0,99,0,99,'N');

INSERT INTO INPUT_GRAPH VALUES('t500','T',500,NULL, NULL,
500,124750,0,'N',0,499,0,499,'N');

INSERT INTO INPUT_GRAPH VALUES('t1k','T',1000,NULL, NULL,
1000,499500,0,'N',0,999,0,999,'N');

INSERT INTO INPUT_GRAPH VALUES('t2k','T',2000,NULL, NULL,
2000,1999000,0,'N',0,1999,0,1999,'N');

INSERT INTO INPUT_GRAPH VALUES('m4ki_2','M',4096,2, NULL,
8192,8190,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('m1ki_8','M',1024,8, NULL,
8192,8184,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('m256_32','M',256,32, NULL,
8192,8160,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('m64_128','M',64,128, NULL,
8192,8064,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('m16_512','M', 16, 512, NULL,
8192,7680,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('m4_2ki','M', 4, 2048, NULL,
8192,6144,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('p1k','P',1000,NULL, NULL,
1000,999,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('p2k','P',2000,NULL, NULL,
2000,1999,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('p3k','P',3000,NULL, NULL,
3000,2999,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('p4k','P',4000,NULL, NULL,
4000,3999,0,'N',0,1,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('s2k_1','S', 2000, 1, NULL,
2000,4000,0,'N',2,2,2,2,'Y');

INSERT INTO INPUT_GRAPH VALUES('s2k_2','S', 2000, 2, NULL,
2000,6000,0,'N',3,3,3,3,'Y');

INSERT INTO INPUT_GRAPH VALUES('s2k_3','S', 2000, 3, NULL,
2000,8000,0,'N',4,4,4,4,'Y');

INSERT INTO INPUT_GRAPH VALUES('s2k_4','S', 2000, 4, NULL,
2000,10000,0,'N',5,5,5,5,'Y');

INSERT INTO INPUT_GRAPH VALUES('s2k_5','S', 2000, 5, NULL,
2000,12000,0,'N',6,6,6,6,'Y');

INSERT INTO INPUT_GRAPH VALUES('s1k_1','S', 1000, 1, NULL,
1000,2000,0,'N',2,2,2,2,'Y');

INSERT INTO INPUT_GRAPH VALUES('s1k_2','S', 1000, 2, NULL,
1000,3000,0,'N',3,3,3,3,'Y');

INSERT INTO INPUT_GRAPH VALUES('s1k_3','S', 1000, 3, NULL,
1000,4000,0,'N',4,4,4,4,'Y');

INSERT INTO INPUT_GRAPH VALUES('s1k_4','S', 1000, 4, NULL,
1000,5000,0,'N',5,5,5,5,'Y');

INSERT INTO INPUT_GRAPH VALUES('s1k_5','S', 1000, 5, NULL,
1000,6000,0,'N',6,6,6,6,'Y');

INSERT INTO INPUT_GRAPH VALUES('u1k_50k','U', 1000, 50000, NULL,
1000,50000,0,'N',46,51,46,51,'Y');

INSERT INTO INPUT_GRAPH VALUES('u1k_125k','U', 1000, 125000, NULL,
1000,125000,0,'N',122,127,122,127,'Y');

INSERT INTO INPUT_GRAPH VALUES('u1k_250k','U', 1000, 250000, NULL,
1000,250000,0,'N',248,251,248,251,'Y');

INSERT INTO INPUT_GRAPH VALUES('u2k_200k','U', 2000, 200000, NULL,
2000,200000,0,'N',98,101,98,101,'Y');

INSERT INTO INPUT_GRAPH VALUES('u2k_500k','U', 2000, 500000, NULL,
2000,500000,0,'N',248,251,248,251,'Y');

INSERT INTO INPUT_GRAPH VALUES('u2k_1m','U', 2000, 1000000, NULL,
2000,1000000,0,'N',499,502,499,502,'Y');

INSERT INTO INPUT_GRAPH VALUES('a1k_50k','A', 1000, 50000, NULL,
1000,50000,0,'N',0,102,0,102,'N');

INSERT INTO INPUT_GRAPH VALUES('a1k_125k','A', 1000, 125000, NULL,
1000,125000,0,'N',0,250,0,250,'N');

INSERT INTO INPUT_GRAPH VALUES('a1k_250k','A', 1000, 250000, NULL,
1000,250000,0,'N',0,500,0,501,'N');

INSERT INTO INPUT_GRAPH VALUES('a2k_200k','A', 2000, 200000, NULL,
2000,200000,0,'N',0,201,0,201,'N');

INSERT INTO INPUT_GRAPH VALUES('a2k_500k','A', 2000, 500000, NULL,
2000,500000,0,'N',0,500,0,500,'N');

INSERT INTO INPUT_GRAPH VALUES('a2k_1m','A', 2000, 1000000, NULL,
2000,1000000,0,'N',0,1000,0,1000,'N');

INSERT INTO INPUT_GRAPH VALUES('y1k_4k','Y', 1000, 4000, NULL,
5000,4999,0,'N',0,1000,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('y1k_8k','Y', 1000, 8000, NULL,
9000,8999,0,'N',0,1000,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('y500_4k','Y', 500, 4000, NULL,
4500,4499,0,'N',0,500,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('y500_8k','Y', 500, 8000, NULL,
8500,8499,0,'N',0,500,0,1,'N');

INSERT INTO INPUT_GRAPH VALUES('w1k_1k','W', 1000, 1000, NULL,
2000,1000000,0,'N',0,1000,0,1000,'N');

INSERT INTO INPUT_GRAPH VALUES('x10k','X', 10000, NULL, NULL,
20001,20000,0,'N',0,10000,0,10000,'N');

-- INSERT INTO INPUT_GRAPH VALUES(FILE_ID, GTYPE, PARAM_1, PARAM_2, PARAM_3,
-- NUM_NODES, NUM_EDGES, DUP_EDGES, LOOPS, MIN_IN_DEGREE, MAX_IN_DEGREE,
--	MIN_OUT_DEGREE, MAX_OUT_DEGREE, CYCLES);

-- ============================================================================
-- Automatically Added Input Graph Data:
-- ============================================================================

-- DO NOT DELETE THIS MARK
