-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/input_join1.sql
-- Purpose:	Database for Benchmark Runs: Data of Join1 Input Data Sets
-- Last Change:	22.03.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- More Data on Data Files That are Input Data Sets for the Join1 Benchmark:
-- ============================================================================

-- CREATE TABLE INPUT_JOIN1 (
--	FILE_ID        VARCHAR(10) NOT NULL,
--	NUM_NODES      NUMERIC(12) NOT NULL,
--	C2_SIZE        NUMERIC(12) NOT NULL,
--	C3_SIZE        NUMERIC(12) NOT NULL,
--	C4_SIZE        NUMERIC(12) NOT NULL,
--	D1_SIZE        NUMERIC(12) NOT NULL,
--	D2_SIZE        NUMERIC(12) NOT NULL,
--	A_SIZE         NUMERIC(12) NOT NULL,
--	B1_SIZE        NUMERIC(12) NOT NULL,
--	B2_SIZE        NUMERIC(12) NOT NULL,
--	C1_SIZE        NUMERIC(12) NOT NULL,
--	A_COST         NUMERIC(12) NOT NULL,
--	B1_COST        NUMERIC(12) NOT NULL,
--	B2_COST        NUMERIC(12) NOT NULL,
--	C1_COST        NUMERIC(12) NOT NULL,
--	CONSTRAINT INPUT_JOIN1_PK
--		PRIMARY KEY(FILE_ID),
--	CONSTRAINT INPUT_JOIN1_REF_INPUT_FILE
--		FOREIGN KEY(FILE_ID) REFERENCES INPUT_FILE,
--	CONSTRAINT INPUT_JOIN1_NUM_NODES_NONNEGATIVE
--		CHECK(NUM_NODES >= 0),
--	CONSTRAINT INPUT_JOIN1_A_SIZE_NONNEGATIVE
--		CHECK(A_SIZE >= 0),
--	CONSTRAINT INPUT_JOIN1_B1_SIZE_NONNEGATIVE
--		CHECK(B1_SIZE >= 0),
--	CONSTRAINT INPUT_JOIN1_B2_SIZE_NONNEGATIVE
--		CHECK(B2_SIZE >= 0),
--	CONSTRAINT INPUT_JOIN1_C1_SIZE_NONNEGATIVE
--		CHECK(C1_SIZE >= 0),
--	CONSTRAINT INPUT_JOIN1_C2_SIZE_NONNEGATIVE
--		CHECK(C2_SIZE >= 0),
--	CONSTRAINT INPUT_JOIN1_C3_SIZE_NONNEGATIVE
--		CHECK(C3_SIZE >= 0),
--	CONSTRAINT INPUT_JOIN1_C4_SIZE_NONNEGATIVE
--		CHECK(C4_SIZE >= 0),
--	CONSTRAINT INPUT_JOIN1_D1_SIZE_NONNEGATIVE
--		CHECK(D1_SIZE >= 0),
--	CONSTRAINT INPUT_JOIN1_D2_SIZE_NONNEGATIVE
--		CHECK(D2_SIZE >= 0),
--	CONSTRAINT INPUT_JOIN1_A_COST_NONNEGATIVE
--		CHECK(A_COST >= 0),
--	CONSTRAINT INPUT_JOIN1_B1_COST_NONNEGATIVE
--		CHECK(B1_COST >= 0),
--	CONSTRAINT INPUT_JOIN1_B2_COST_NONNEGATIVE
--		CHECK(B2_COST >= 0),
--	CONSTRAINT INPUT_JOIN1_C1_COST_NONNEGATIVE
--		CHECK(C1_COST >= 0),
--	CONSTRAINT INPUT_JOIN1_A_COST_GE_A_SIZE
--		CHECK(A_COST >= A_SIZE),
--	CONSTRAINT INPUT_JOIN1_B1_COST_GE_B1_SIZE
--		CHECK(B1_COST >= B1_SIZE),
--	CONSTRAINT INPUT_JOIN1_B2_COST_GE_B2_SIZE
--		CHECK(B2_COST >= B2_SIZE),
--	CONSTRAINT INPUT_JOIN1_C1_COST_GE_C1_SIZE
--		CHECK(C1_COST >= C1_SIZE));

-- A_SIZE and so on are the number of facts for the predicate.
-- The input file contains the predicates D1, D2, C2, C3, C4.
-- The other predicates are derived by means of the following rules:
--	a(X, Y)  :- b1(X, Z), b2(Z, Y).
--	b1(X, Y) :- c1(X, Z), c2(Z, Y).
--	b2(X, Y) :- c3(X, Z), c4(Z, Y).
--	c1(X, Y) :- d1(X, Z), d2(Z, Y).

-- A_COST and so on are the number of instances of the rule that derives A.


-- ============================================================================
-- INSERT Statements for Join1 Input Data Sets:
-- ============================================================================

-- INSERT INTO INPUT_JOIN1 VALUES(FILE_ID,
--	NUM_NODES,
--	C2_SIZE, C3_SIZE, C4_SIZE, D1_SIZE, D2_SIZE,
--	A_SIZE, B1_SIZE, B2_SIZE, C1_SIZE,
--	A_COST,
--	B1_COST,
--	B2_COST,
--	C1_COST);

INSERT INTO INPUT_JOIN1 VALUES('j1k10k',
	1000,
	10000, 10000, 10000, 10000, 10000,
	1000000, 634088, 95954, 95570,
	60832827,
	955753,
	100004,
	99997);

INSERT INTO INPUT_JOIN1 VALUES('j1k50k',
	1000,
	50000, 50000, 50000, 50000, 50000,
	1000000, 1000000, 930032, 925994,
	930032000,
	46300694,
	2500004,
	2499994);

INSERT INTO INPUT_JOIN1 VALUES('j1k250k',
	1000,
	250000, 250000, 250000, 250000, 250000,
	1000000, 1000000, 1000000, 1000000,
	1000000000,
	250000000,
	62500041,
	62500086);


-- ============================================================================
-- Automatically Added Input Set Data:
-- ============================================================================

-- DO NOT DELETE THIS MARK
