-- ============================================================================
-- Project:	ddbench - Deductive System and Database Benchmarks
-- Filename:	db/mariadb.sql
-- Purpose:	Database for Benchmark Runs: Data for the MariaDB System
-- Last Change:	02.02.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- System to be Tested/Compared:
-- ============================================================================

-- INSERT INTO TEST_SYS VALUES (
--	SYS, SEQ_NO, FULL_NAME, STYPE,
--	URL,
--	REMARK);

INSERT INTO TEST_SYS VALUES (
	'mariadb', 33, 'MariaDB', 'RDB',
	'https://www.mariadb.com',
	NULL);


-- ============================================================================
-- Versions of the Test System:
-- ============================================================================

-- INSERT INTO SYS_VER VALUES (
--	SYS, VER, VER_ADDTEXT, VER_DATE,
--	REMARK);

INSERT INTO SYS_VER VALUES (
	'mariadb', '10.0.35', '', '2018-05-03',
	NULL);

INSERT INTO SYS_VER VALUES (
	'mariadb', '10.3.9', '', '2018-08-15',
	NULL);

INSERT INTO SYS_VER VALUES (
	'mariadb', '10.3.12', '', '2018-08-15',
	NULL);

INSERT INTO SYS_VER VALUES (
	'mariadb', '10.3.17', '', '2019-07-31',
	NULL);

-- ============================================================================
-- Installed Program Versions on Machines:
-- ============================================================================

-- INSERT INTO SYS_INSTALL VALUES (
-- 	SYS, VER, MACHINE, INST_NO,
-- 	COMPILER,
-- 	STATUS, -- 'C': current version, 'P' previous, 'A' alternate, ' ' other
-- 	REMARK);

-- Installations on main test machine:

INSERT INTO SYS_INSTALL VALUES (
	'mariadb', '10.0.35', 'dbs1', 1,
	'',
	'P',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'mariadb', '10.3.9', 'dbs1', 2,
	'',
	'A',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'mariadb', '10.3.12', 'dbs1', 3,
	'',
	'C',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'mariadb', '10.3.17', 'dbs1', 4,
	'',
	'C',
	NULL);

-- Installations on development machine:


-- Installations on old test machine:

INSERT INTO SYS_INSTALL VALUES (
	'mariadb', '10.0.35', 'dbs0', 1,
	'',
	'P',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'mariadb', '10.3.9', 'dbs0', 2,
	'',
	'C',
	NULL);


-- ============================================================================
-- Benchmark Implementations:
-- ============================================================================

-- INSERT INTO BENCH_IMPL VALUES (
-- 	SYS, BENCH, IMPL, STATUS, -- STATUS='B': best, 'A' alternate, ' ' other
-- 	DESCRIPTION);

-- ----------------------------------------------------------------------------
-- DBLP Benchmark:
-- ----------------------------------------------------------------------------


-- ----------------------------------------------------------------------------
-- Join1 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'j1axy', 'u', 'B',
	'Join1, a(X,Y) [V0: unindex]'); -- CTE

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'j1axy', 'p', ' ',
	'Join1, a(X,Y) [V1: a,b as PK]'); -- CTE

-- ----------------------------------------------------------------------------
-- TCFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'tcff', 'm', 'A',
	'transitive closure for MariaDB, storage manager MEMORY (BTREE index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'tcff', 'mhash', 'A',
	'transitive closure for MariaDB, storage manager MEMORY (HASH index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'tcff', 'mbtree', 'A',
	'transitive closure for MariaDB, storage manager MEMORY (BTREE index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'tcff', 'i', 'B',
	'transitive closure for MariaDB, storage manager InnoDB (BTREE index)');

-- ----------------------------------------------------------------------------
-- TCBF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'tcbf', '', 'B',
	'transitive closure for MariaDB, unknown storage manager');

-- ----------------------------------------------------------------------------
-- TCFB Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'tcfb', '', 'B',
	'transitive closure for MariaDB, unknown storage manager');

-- ----------------------------------------------------------------------------
-- Wine Ontology Benchmark:
-- ----------------------------------------------------------------------------

-- ----------------------------------------------------------------------------
-- SGFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'sgff', 'i', 'B',
	'same generation for MariaDB, storage manager InnoDB (BTREE index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'sgff', 'mhash', 'A',
	'same generation for MariaDB, storage manager MEMORY (HASH index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'sgff', 'mbtree', 'A',
	'same generation for MariaDB, storage manager MEMORY (BTREE index)');


-- ----------------------------------------------------------------------------
-- Path2 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path2', 'mbtree', 'A',
	'path2 [ff] for mariadb, storage manager MEMORY (BTREE index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path2', 'mhash', 'A',
	'path2 [ff] for mariadb, storage manager MEMORY (HASH index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path2', 'i', 'B',
	'path2 [ff] for mariadb, storage manager InnoDB (BTREE index)');

-- ----------------------------------------------------------------------------
-- Path3 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path3L', 'mbtree', 'A',
	'path3 [ff] for mariadb, storage manager MEMORY (BTREE index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path3L', 'mhash', 'A',
	'path3 [ff] for mariadb, storage manager MEMORY (HASH index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path3L', 'i', 'B',
	'path3 [ff] for mariadb, storage manager InnoDB (BTREE index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path3R', 'mbtree', 'A',
	'path3 [ff] for mariadb, storage manager MEMORY (BTREE index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path3R', 'mhash', 'A',
	'path3 [ff] for mariadb, storage manager MEMORY (HASH index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path3R', 'i', 'B',
	'path3 [ff] for mariadb, storage manager InnoDB (BTREE index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path3F', 'mbtree', 'A',
	'path3 [ff] for mariadb, storage manager MEMORY (BTREE index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path3F', 'mhash', 'A',
	'path3 [ff] for mariadb, storage manager MEMORY (HASH index)');

INSERT INTO BENCH_IMPL VALUES (
	'mariadb', 'path3F', 'i', 'B',
	'path3 [ff] for mariadb, storage manager InnoDB (BTREE index)');
