-- ============================================================================
-- Project:	ddbench - Deductive System and Database Benchmarks
-- Filename:	db/psql.sql
-- Purpose:	Database for Benchmark Runs: Data for the PostgreSQL System
-- Last Change:	02.02.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- System to be Tested/Compared:
-- ============================================================================

-- INSERT INTO TEST_SYS VALUES (
--	SYS, SEQ_NO, FULL_NAME, STYPE,
--	URL,
--	REMARK);

INSERT INTO TEST_SYS VALUES (
	'psql', 34, 'PostgreSQL', 'RDB',
	'https://www.postgresql.org',
	NULL);


-- ============================================================================
-- Versions of the Test System:
-- ============================================================================

-- INSERT INTO SYS_VER VALUES (
--	SYS, VER, VER_ADDTEXT, VER_DATE,
--	REMARK);

INSERT INTO SYS_VER VALUES (
	'psql', '9.2.24', '', '2017-11-09',
	NULL);

INSERT INTO SYS_VER VALUES (
	'psql', '9.4.15', '', '2017-11-09',
	NULL);

INSERT INTO SYS_VER VALUES (
	'psql', '9.4.19', '', '2018-08-09',
	NULL);

INSERT INTO SYS_VER VALUES (
	'psql', '11.5', '', '2019-08-08',
	NULL);

-- ============================================================================
-- Installed Program Versions on Machines:
-- ============================================================================

-- INSERT INTO SYS_INSTALL VALUES (
-- 	SYS, VER, MACHINE, INST_NO,
-- 	COMPILER,
-- 	STATUS, -- 'C': current version, 'P' previous, 'A' alternate, ' ' other
-- 	REMARK);

-- Installations on main test machine:

INSERT INTO SYS_INSTALL VALUES (
	'psql', '9.4.15', 'dbs1', 1,
	'',
	'C',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'psql', '9.4.19', 'dbs1', 2,
	'',
	'A',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'psql', '11.5', 'dbs1', 3,
	'',
	'A',
	NULL);

-- Installations on development machine:

INSERT INTO SYS_INSTALL VALUES (
	'psql', '9.2.24', 'bach', 1,
	'gcc (GCC) 4.8.5 20150623 (Red Hat 4.8.5-28), 64-bit',
	'C',
	NULL);

-- Installations on old test machine:

INSERT INTO SYS_INSTALL VALUES (
	'psql', '9.4.15', 'dbs0', 1,
	'',
	'C',
	NULL);


-- ============================================================================
-- Benchmark Implementations:
-- ============================================================================

-- INSERT INTO BENCH_IMPL VALUES (
-- 	SYS, BENCH, IMPL, STATUS, -- STATUS='B': best, 'A' alternate, ' ' other
-- 	DESCRIPTION);

-- ----------------------------------------------------------------------------
-- DBLP Benchmark:
-- ----------------------------------------------------------------------------


-- ----------------------------------------------------------------------------
-- Join1 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'j1axy', 'u', ' ',
	'Join1, a(X,Y) [V0: unindex]'); -- CTE

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'j1axy', 'p', 'B',
	'Join1, a(X,Y) [V1: a,b as PK]'); -- CTE

-- ----------------------------------------------------------------------------
-- TCFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'tcff', '', 'B',
	'transitive closure [ff] for PostgreSQL');

-- ----------------------------------------------------------------------------
-- TCBF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'tcbf', '', 'B',
	'transitive closure [bf] for PostgreSQL');

-- ----------------------------------------------------------------------------
-- TCFB Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'tcfb', '', 'B',
	'transitive closure [fb] for PostgreSQL');

-- ----------------------------------------------------------------------------
-- Path2 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'path2', '', 'B',
	'path2 [ff] for PostgreSQL');

-- ----------------------------------------------------------------------------
-- Path3 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'path3F', '', 'B',
	'path3F [ff] for PostgreSQL');

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'path3R', '', 'B',
	'path3R [ff] for PostgreSQL');

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'path3L', '', 'B',
	'path3L [ff] for PostgreSQL');


-- ----------------------------------------------------------------------------
-- Wine Ontology Benchmark:
-- ----------------------------------------------------------------------------

-- ----------------------------------------------------------------------------
-- SGFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'psql', 'sgff', '', 'B',
	'same generation [ff] for PostgreSQL');
