-- ============================================================================
-- Project:	ddbench - Deductive System and Database Benchmarks
-- Filename:	db/sqlite.sql
-- Purpose:	Database for Benchmark Runs: Data for the SQLite 3 System
-- Last Change:	02.02.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- System to be Tested/Compared:
-- ============================================================================

-- INSERT INTO TEST_SYS VALUES (
--	SYS, SEQ_NO, FULL_NAME, STYPE,
--	URL,
--	REMARK);

INSERT INTO TEST_SYS VALUES (
	'sqlite3', 32, 'SQLite 3', 'RDB',
	'https://www.sqlite.org/index.html',
	NULL);


-- ============================================================================
-- Versions of the Test System:
-- ============================================================================

-- INSERT INTO SYS_VER VALUES (
--	SYS, VER, VER_ADDTEXT, VER_DATE,
--	REMARK);

INSERT INTO SYS_VER VALUES (
	'sqlite3', '3.8.7.1', '', '2014-10-29',
	NULL);

INSERT INTO SYS_VER VALUES (
	'sqlite3', '3.22.0', '', '2018-01-22',
	NULL);

INSERT INTO SYS_VER VALUES (
	'sqlite3', '3.24.0', '', '2018-06-04',
	NULL);

INSERT INTO SYS_VER VALUES (
	'sqlite3', '3.25.1', '', '2018-09-18',
	NULL);

INSERT INTO SYS_VER VALUES (
	'sqlite3', '3.25.2', '', '2018-09-25',
	NULL);

INSERT INTO SYS_VER VALUES (
	'sqlite3', '3.26.0', '', '2018-12-01',
	NULL);

INSERT INTO SYS_VER VALUES (
	'sqlite3', '3.30.0', '', '2019-10-04',
	NULL);

-- ============================================================================
-- Installed Program Versions on Machines:
-- ============================================================================

-- INSERT INTO SYS_INSTALL VALUES (
-- 	SYS, VER, MACHINE, INST_NO,
-- 	COMPILER,
-- 	STATUS, -- 'C': current version, 'P' previous, 'A' alternate, ' ' other
-- 	REMARK);

-- Installations on main test machine:

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.8.7.1', 'dbs1', 1,
	'',
	' ',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.22.0', 'dbs1', 2,
	'',
	' ',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.24.0', 'dbs1', 3,
	'',
	' ',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.25.1', 'dbs1', 4,
	'',
	'A',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.25.2', 'dbs1', 5,
	'',
	'P',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.26.0', 'dbs1', 6,
	'',
	'C',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.30.0', 'dbs1', 7,
	'',
	'C',
	NULL);

-- Installations on development machine:


-- Installations on old test machine:

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.8.7.1', 'dbs0', 1,
	'',
	' ',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.22.0', 'dbs0', 2,
	'',
	' ',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.24.0', 'dbs0', 3,
	'',
	' ',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.25.1', 'dbs0', 4,
	'',
	'C',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'sqlite3', '3.25.2', 'dbs0', 5,
	'',
	'A',
	NULL);


-- ============================================================================
-- Benchmark Implementations:
-- ============================================================================

-- INSERT INTO BENCH_IMPL VALUES (
-- 	SYS, BENCH, IMPL, STATUS, -- STATUS='B': best, 'A' alternate, ' ' other
-- 	DESCRIPTION);

-- ----------------------------------------------------------------------------
-- DBLP Benchmark:
-- ----------------------------------------------------------------------------


-- ----------------------------------------------------------------------------
-- Join1 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'j1axy', 'u', 'B',
	'Join1, a(X,Y) [V0: unindex]'); -- CTE

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'j1axy', 'p', ' ',
	'Join1, a(X,Y) [V1: a,b as PK]'); -- CTE

-- ----------------------------------------------------------------------------
-- TCFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'tcff', '', 'B',
	'transitive closure [ff] for SQLite3');

-- ----------------------------------------------------------------------------
-- TCBF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'tcbf', '', 'B',
	'transitive closure [bf] for SQLite3');

-- ----------------------------------------------------------------------------
-- TCFB Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'tcfb', '', 'B',
	'transitive closure [fb] for SQLite3');

-- ----------------------------------------------------------------------------
-- Wine Ontology Benchmark:
-- ----------------------------------------------------------------------------

-- ----------------------------------------------------------------------------
-- SGFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'sgff', '', 'B',
	'same generation [ff] for SQLite3');


-- ----------------------------------------------------------------------------
-- Path2 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'path2', '', 'B',
	'path2 [ff] for sqlite');

-- ----------------------------------------------------------------------------
-- Path3 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'path3F', '', 'B',
	'path3f [ff] for sqlite');

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'path3R', '', 'B',
	'path3r [ff] for sqlite');

INSERT INTO BENCH_IMPL VALUES (
	'sqlite3', 'path3L', '', 'B',
	'path3l [ff] for sqlite');
