-- ============================================================================
-- Project:	ddbench - Deductive System and Database Benchmarks
-- Filename:	db/swipl.sql
-- Purpose:	Database for Benchmark Runs: Data for SWI Prolog
-- Last Change:	02.02.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- System to be Tested/Compared:
-- ============================================================================

-- INSERT INTO TEST_SYS VALUES (
--	SYS, SEQ_NO, FULL_NAME, STYPE,
--	URL,
--	REMARK);

INSERT INTO TEST_SYS VALUES (
	'swipl', 12, 'SWI-Prolog', 'Prolog',
	'http://www.swi-prolog.org/',
	NULL);


-- ============================================================================
-- Versions of the Test System:
-- ============================================================================

-- INSERT INTO SYS_VER VALUES (
--	SYS, VER, VER_ADDTEXT, VER_DATE,
--	REMARK);

INSERT INTO SYS_VER VALUES (
	'swipl', '7.7.15', ' (x86_64-linux)', '2018-06-01',
	NULL);

INSERT INTO SYS_VER VALUES (
	'swipl', '7.5.15', ' (x86_64-linux)', '2017-09-12',
	NULL);

INSERT INTO SYS_VER VALUES (
	'swipl', '7.6.4', ' (x86_64-linux)', '2018-01-12',
	NULL);

INSERT INTO SYS_VER VALUES (
	'swipl', '7.7.7', ' (x86_64-linux)', '2017-12-21',
	NULL);


-- ============================================================================
-- Installed Program Versions on Machines:
-- ============================================================================

-- INSERT INTO SYS_INSTALL VALUES (
-- 	SYS, VER, MACHINE, INST_NO,
-- 	COMPILER,
-- 	STATUS, -- 'C': current version, 'P' previous, 'A' alternate, ' ' other
-- 	REMARK);

-- Installations on main test machine:

INSERT INTO SYS_INSTALL VALUES (
	'swipl', '7.7.15', 'dbs1', 1,
	'',
	'C',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'swipl', '7.5.15', 'dbs1', 2,
	'',
	'P',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'swipl', '7.6.4', 'dbs1', 3,
	'',
	' ',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'swipl', '7.7.7', 'dbs1', 4,
	'',
	' ',
	NULL);


-- Installation on development machine:

INSERT INTO SYS_INSTALL VALUES (
	'swipl', '7.6.4', 'bach', 3,
	'',
	'C',
	NULL);

-- Installations on old test machine:

INSERT INTO SYS_INSTALL VALUES (
	'swipl', '7.7.15', 'dbs0', 1,
	'',
	'C',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'swipl', '7.5.15', 'dbs0', 2,
	'',
	'P',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'swipl', '7.6.4', 'dbs0', 3,
	'',
	'C',
	NULL);

INSERT INTO SYS_INSTALL VALUES (
	'swipl', '7.7.7', 'dbs0', 4,
	'',
	'C',
	NULL);


-- ============================================================================
-- Benchmark Implementations:
-- ============================================================================

-- INSERT INTO BENCH_IMPL VALUES (
-- 	SYS, BENCH, IMPL, STATUS, -- STATUS='B': best, 'A' alternate, ' ' other
-- 	DESCRIPTION);

-- ----------------------------------------------------------------------------
-- DBLP Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'dblp', '', 'B',
	'DBLP Benchmark');

-- ----------------------------------------------------------------------------
-- Join1 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'j1axyd', '', 'B',
	'Join1 with duplicates, a(X,Y)');

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'j1axy', '', 'B',
	'Join1, a(X,Y)');

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'j1axy', 'a', ' ',
	'Join1, a(X,Y) [V1: only a tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'j1axy', 'all', 'B',
	'Join1, a(X,Y) [V2: all derived preds tabled]');
	
INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'j1axy', 'unt', ' ',
	'Join1, a(X,Y) [V0: no tabling]');

-- ----------------------------------------------------------------------------
-- TCFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'tcff', '', 'B',
	'tc(X,Y) [tc tabled]');

-- ----------------------------------------------------------------------------
-- TCBF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'tcbf', '', 'B',
	'tc(1,X) [tc tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'tcbfs', 'sldm', 'B',
	'tc(1,X) [with SLDMagic, all preds tabled]');

-- ----------------------------------------------------------------------------
-- TCFB Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'tcfb', '', 'B',
	'tc(X,1) [tc tabled]');

-- ----------------------------------------------------------------------------
-- Wine Ontology Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'swipl', 'wine', '', 'B',
	'wine ontology');

