-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/v_doc.sql
-- Purpose:	Benchmark DB: Views to Produce Table Data in Markdown Format
-- Last Change:	04.10.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2018-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ############################################################################
-- Output Table Data in Markdown Format (for Documentation)
-- ############################################################################


-- ============================================================================
-- BENCH_IMPL_MD:
-- ============================================================================

CREATE VIEW BENCH_IMPL_MD AS
SELECT 0 AS SECTION, ' ' AS SYS, ' ' AS BENCH, ' ' AS IMPL,
	'|SYS|BENCH|IMPL|STATUS|DESCRIPTION|' AS MD
UNION ALL
SELECT 1 AS SECTION, ' ' AS SYS, ' ' AS BENCH, ' ' AS IMPL,
	'|----|-----|----|------|-----------|' AS MD
UNION ALL
SELECT 2 AS LINE, SYS, BENCH, IMPL,
       '|' || SYS || '|' ||  BENCH || '|' || IMPL || '|' || STATUS ||
	'|' || DESCRIPTION || '|' AS MD
FROM   BENCH_IMPL
ORDER BY SECTION, SYS, BENCH, IMPL;

-- ============================================================================
-- INPUT_FILE_MD:
-- ============================================================================

CREATE VIEW INPUT_FILE_MD AS
SELECT 0 AS SECTION, 0 AS SEQ_NO,
	'|FILE_ID|SEQ_NO|ITYPE|LINES|BYTES|FILENAME|' AS MD
UNION ALL
SELECT 1 AS SECTION, 0 AS SEQ_NO,
	'|-------|-----:|-----|----:|----:|--------|' AS MD
UNION ALL
SELECT 2 AS SECTION, SEQ_NO,
       '|' || FILE_ID || '|' ||  SEQ_NO || '|' || ITYPE || '|' || LINES ||
	'|' || BYTES || '|' || FILENAME || '|' AS MD
FROM   INPUT_FILE
ORDER BY SECTION, SEQ_NO;


-- ============================================================================
-- INPUT_GRAPH_MD:
-- ============================================================================

CREATE VIEW INPUT_GRAPH_MD AS
SELECT 0 AS SECTION, 0 AS SEQ_NO,
	'|FILE_ID|' ||
	'GTYPE|PARAM_1|PARAM_2|' ||
	'NUM_NODES|NUM_EDGES|' ||
	'DUP_EDGES|LOOPS|' ||
	'MIN_IN_DEGREE|MAX_IN_DEGREE|' ||
	'MIN_OUT_DEGREE|MAX_OUT_DEGREE|' ||
	'CYCLES|' AS MD
UNION ALL
SELECT 1 AS SECTION, 0 AS SEQ_NO,
	'|-------|' ||
	'-----|------:|------:|' ||
	'--------:|--------:|' ||
	'--------:|:---:|' ||
	'------------:|------------:|' ||
	'-------------:|-------------:|' ||
	':----:|' AS MD
UNION ALL
SELECT 2 AS SECTION, F.SEQ_NO,
       '|' || G.FILE_ID || '|' ||
	GTYPE || '|' ||
	(CASE WHEN PARAM_1 IS NULL THEN ' ' ELSE CAST(PARAM_1 AS VARCHAR) END)
        || '|' ||
	(CASE WHEN PARAM_2 IS NULL THEN ' ' ELSE CAST(PARAM_2 AS VARCHAR) END)
	|| '|' ||
	NUM_NODES || '|' ||  NUM_EDGES || '|' ||
	DUP_EDGES || '|' || LOOPS || '|' ||
	MIN_IN_DEGREE || '|' || MAX_IN_DEGREE || '|' ||
	MIN_OUT_DEGREE || '|' || MAX_OUT_DEGREE || '|' ||
	CYCLES || '|' || '|'
	AS MD
FROM   INPUT_GRAPH G, INPUT_FILE F
WHERE  G.FILE_ID = F.FILE_ID
ORDER BY SECTION, SEQ_NO;


-- ============================================================================
-- BENCH_COST_MD:
-- ============================================================================

CREATE VIEW BENCH_COST_MD AS
SELECT 0 AS SECTION, 0 AS SEQ_NO,
	'|BENCH|FILE_ID|' ||
	'SIZE|ITER|INST|' AS MD
UNION ALL
SELECT 1 AS SECTION, 0 AS SEQ_NO,
	'|-------|--------|' ||
	'------------:|------:|------------:|' AS MD
UNION ALL
SELECT 2 AS SECTION, F.SEQ_NO,
       '|' || B.BENCH || '|' || B.FILE_ID || '|' ||
	B.SIZE || '|' || B.ITER || '|' || B.INST || '|'
	AS MD
FROM   BENCH_COST B, INPUT_FILE F
WHERE  B.FILE_ID = F.FILE_ID
ORDER BY SECTION, SEQ_NO;

