-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/v_graph.sql
-- Purpose:	Benchmark DB: Views to Produce Graph Data in Various Formats
-- Last Change:	04.10.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2018-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ############################################################################
-- Graph Data in Various Formats:
-- ############################################################################


-- ============================================================================
-- Graph Data as LaTeX:
-- ============================================================================

CREATE VIEW INPUT_GRAPH_LATEX AS
SELECT	G.FILE_ID,
	REPLACE(G.FILE_ID, '_', '\_') || '&' ||
	G.NUM_NODES || '&' || G.NUM_EDGES || '&' ||
--	G.MIN_IN_DEGREE || '&' || G.MAX_IN_DEGREE || '&' ||
--	G.MIN_OUT_DEGREE || '&' || G.MAX_OUT_DEGREE || '&' ||
        (CASE WHEN G.MIN_IN_DEGREE = G.MAX_IN_DEGREE
		THEN G.MIN_IN_DEGREE || '&'
		ELSE G.MIN_IN_DEGREE || '--' || G.MAX_IN_DEGREE || '&' END) ||
        (CASE WHEN G.MIN_OUT_DEGREE = G.MAX_OUT_DEGREE
		THEN G.MIN_OUT_DEGREE || '&'
		ELSE G.MIN_OUT_DEGREE || '--' || G.MAX_OUT_DEGREE || '&' END)||
	(CASE WHEN CYCLES='Y' THEN 'yes'
		WHEN CYCLES='N' THEN 'no'
		ELSE '?' END) || '&' ||
	C.SIZE || '&' ||
		C.ITER || '&' ||
		C.INST || '\\'
		AS LATEX
FROM	INPUT_GRAPH G, INPUT_FILE F, BENCH_COST C
WHERE   G.FILE_ID = F.FILE_ID AND C.FILE_ID = F.FILE_ID AND C.BENCH = 'tcff'
ORDER BY F.SEQ_NO;

-- ============================================================================
-- Graph Data as HTML:
-- ============================================================================

CREATE VIEW INPUT_GRAPH_HTML AS
SELECT -2 AS SEQ_NO, NULL AS FILE_ID,
	'<table>' AS HTML
FROM    DUMMY_TAB
UNION ALL
SELECT -1 AS SEQ_NO, NULL AS FILE_ID,
	'<tr>' ||
	'<th class="colGraph">' || 'Graph'          || '</th>' || '
	' || '<th class="colNodes"   >' || 'Nodes'           || '</th>' || '
	' || '<th class="colEdges"   >' || 'Edges'           || '</th>' || '
	' || '<th class="colInDeg"   >' || 'In-Deg.'         || '</th>' || '
	' || '<th class="colOutDeg"  >' || 'Out-Deg.'        || '</th>' || '
	' || '<th class="colCyc"     >' || 'Cyc.'            || '</th>' || '
	' || '<th class="colTCSize"  >' || 'TC&nbsp;Size.'   || '</th>' || '
	' || '<th class="colIter"    >' || 'Iter.'           || '</th>' || '
	' || '<th class="colRuleInst">' || 'Rule&nbsp;Inst.' || '</th>' || '
	' || '</tr>'
	AS HTML
FROM    DUMMY_TAB
UNION ALL
SELECT	F.SEQ_NO, F.FILE_ID,
	'<tr>' ||
	'<td class="colGraph">' ||
		'<a href="data_tsv/' || F.FILENAME || '.tsv">' ||
		F.FILE_ID || '</a>' || '</td>' || '
	' || '<td class="colNodes"   >' || NUM_NODES || '</td>' || '
	' || '<td class="colEdges"   >' || NUM_EDGES || '</td>' || '
	' || '<td class="colInDeg"   >' ||
		(CASE WHEN G.MIN_IN_DEGREE = G.MAX_IN_DEGREE
			THEN CAST(G.MIN_IN_DEGREE AS VARCHAR)
			ELSE G.MIN_IN_DEGREE || '-'  || G.MAX_IN_DEGREE END)
	                                             || '</td>' || '
	' || '<td class="colOutDeg"  >' ||
		(CASE WHEN G.MIN_OUT_DEGREE = G.MAX_OUT_DEGREE
			THEN CAST(G.MIN_OUT_DEGREE AS VARCHAR)
			ELSE G.MIN_OUT_DEGREE || '-' || G.MAX_OUT_DEGREE END)
	                                             || '</td>' || '
	' || '<td class="colCyc"     >' ||
		(CASE WHEN CYCLES='Y' THEN 'yes'
			WHEN CYCLES='N' THEN 'no'
			ELSE '?' END)                || '</td>' || '
	' || '<td class="colTCSize"  >' || C.SIZE   || '</td>' || '
	' || '<td class="colIter"    >' || C.ITER   || '</td>' || '
	' || '<td class="colRuleInst">' || C.INST   || '</td>' || '
	' || '</tr>'
	AS HTML
FROM	INPUT_GRAPH G, INPUT_FILE F, BENCH_COST C
WHERE   G.FILE_ID = F.FILE_ID AND C.FILE_ID = F.FILE_ID AND C.BENCH = 'tcff'
UNION ALL
SELECT 1000000 AS SEQ_NO, NULL AS FILE_ID,
	'</table>' AS HTML
FROM    DUMMY_TAB
ORDER BY SEQ_NO;


