-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/v_j1axy.sql
-- Purpose:	Benchmark DB: Views to analyze Join1 a(X,Y) Benchmark Results
-- Last Change:	04.10.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ############################################################################
-- Benchmark Results for Join1 a(X,Y) - Comparison with BAM:
-- ############################################################################


-- ============================================================================
-- Join1 a(X,Y) Benchmark Results (Comparison with BAM on CPU Time):
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

CREATE VIEW J1AXY_CPU AS
SELECT	BAM.FILE_ID,
	BAM.CPU_T AS BAM_CPU,
	XSB.CPU_T AS XSB_CPU,
	(CASE WHEN BAM.CPU_T=0 THEN NULL
		ELSE ROUND(XSB.CPU_T/BAM.CPU_T,1) END)
		AS XSB_F,
	YAP.CPU_T AS YAP_CPU,
	(CASE WHEN BAM.CPU_T=0 THEN NULL
		ELSE ROUND(YAP.CPU_T/BAM.CPU_T,1) END)
		AS YAP_F,
	SOUFFLE.CPU_T AS SOUFFLE_CPU,
	(CASE WHEN BAM.CPU_T=0 THEN NULL
		ELSE ROUND(SOUFFLE.CPU_T/BAM.CPU_T,1) END)
		AS SOUFFLE_F,
	SQLITE.CPU_T AS SQLITE_CPU,
	(CASE WHEN BAM.CPU_T=0 THEN NULL
		ELSE ROUND(SQLITE.CPU_T/BAM.CPU_T,1) END)
		AS SQLITE_F
FROM	(SELECT * FROM BEST_RESULT WHERE SYS='bam'AND BENCH='j1axy')
		BAM
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='xsb' AND BENCH='j1axy')
		XSB
		ON XSB.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='yap' AND BENCH='j1axy')
		YAP
		ON YAP.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='souffle' AND BENCH='j1axy')
		SOUFFLE
		ON SOUFFLE.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='sqlite3' AND BENCH='j1axy')
		SQLITE
		ON SQLITE.FILE_ID = BAM.FILE_ID
	JOIN INPUT_FILE F
		ON BAM.FILE_ID = F.FILE_ID
ORDER BY F.SEQ_NO;

-- ============================================================================
-- Join1 a(X,Y) Benchmark Results (Comparison with BAM on CPU Time) - LaTeX:
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

CREATE VIEW J1AXY_CPU_LATEX AS
SELECT	BAM.FILE_ID,
	RPAD(REPLACE(BAM.FILE_ID, '_', '\_'), 12) || '&' ||
	TO_CHAR(BAM.CPU_T, '9990.999') || '&' ||
	(CASE WHEN XSB.CPU_T IS NULL THEN '         &       ' ELSE
		(TO_CHAR(XSB.CPU_T, '9990.999') || '&' ||
		(CASE WHEN BAM.CPU_T=0 THEN '       '
			ELSE TO_CHAR(XSB.CPU_T/BAM.CPU_T, '9990.9') END))
	END) || '&' ||
	(CASE WHEN YAP.CPU_T IS NULL THEN '         &       ' ELSE
		(TO_CHAR(YAP.CPU_T, '9990.999') || '&' ||
		(CASE WHEN BAM.CPU_T=0 THEN '       '
			ELSE TO_CHAR(YAP.CPU_T/BAM.CPU_T, '9990.9') END))
	END) || '&' ||
	(CASE WHEN SOUFFLE.CPU_T IS NULL THEN '         &       ' ELSE
		(TO_CHAR(SOUFFLE.CPU_T,'9990.999') || '&' ||
		(CASE WHEN BAM.CPU_T=0 THEN '       '
			ELSE TO_CHAR(SOUFFLE.CPU_T/BAM.CPU_T, '9990.9') END))
	END) || '&' ||
	(CASE WHEN SQLITE.CPU_T IS NULL THEN '         &       ' ELSE
		(TO_CHAR(SQLITE.CPU_T,'9990.999') || '&' ||
		(CASE WHEN BAM.CPU_T=0 THEN '       '
			ELSE TO_CHAR(SQLITE.CPU_T/BAM.CPU_T, '9990.9') END))
	END) || '\\'
	AS LATEX
FROM	(SELECT * FROM BEST_RESULT WHERE SYS='bam' AND BENCH='j1axy')
		BAM
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='xsb' AND BENCH='j1axy')
		XSB
		ON XSB.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='yap' AND BENCH='j1axy')
		YAP
		ON YAP.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='souffle' AND BENCH='j1axy')
		SOUFFLE
		ON SOUFFLE.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='sqlite3' AND BENCH='j1axy')
		SQLITE
		ON SQLITE.FILE_ID = BAM.FILE_ID
	JOIN INPUT_FILE F
		ON F.FILE_ID = BAM.FILE_ID
ORDER BY F.SEQ_NO;


-- ============================================================================
-- Join1 a(X,Y) Benchmark Results (Comparison with BAM on REAL Time):
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.
-- This version contains the runtime factors compared with BAM.

CREATE VIEW J1AXY_REAL AS
SELECT	BAM.FILE_ID,
        F.SEQ_NO,
	BAM.REAL_T AS BAM_REAL,
	XSB.REAL_T AS XSB_REAL,
	(CASE WHEN BAM.REAL_T=0 THEN NULL
		ELSE ROUND(XSB.REAL_T/BAM.REAL_T,1) END)
		AS XSB_F,
	YAP.REAL_T AS YAP_REAL,
	(CASE WHEN BAM.REAL_T=0 THEN NULL
		ELSE ROUND(YAP.REAL_T/BAM.REAL_T,1) END)
		AS YAP_F,
	SQLITE.REAL_T AS SQLITE_REAL,
	(CASE WHEN BAM.REAL_T=0 THEN NULL
		ELSE ROUND(SQLITE.REAL_T/BAM.REAL_T,1) END)
		AS SQLITE_F,
	PSQL.REAL_T AS PSQL_REAL,
	(CASE WHEN BAM.REAL_T=0 THEN NULL
		ELSE ROUND(PSQL.REAL_T/BAM.REAL_T,1) END)
		AS PSQL_F,
	MARIA.REAL_T AS MARIA_REAL,
	(CASE WHEN BAM.REAL_T=0 THEN NULL
		ELSE ROUND(MARIA.REAL_T/BAM.REAL_T,1) END)
		AS MARIA_F,
	SOUFFLE.REAL_T AS SOUFFLE_REAL,
	(CASE WHEN BAM.REAL_T=0 THEN NULL
		ELSE ROUND(SOUFFLE.REAL_T/BAM.REAL_T,1) END)
		AS SOUFFLE_F
FROM	(SELECT * FROM BEST_RESULT WHERE SYS='bam'AND BENCH='j1axy')
		BAM
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='xsb' AND BENCH='j1axy')
		XSB
		ON XSB.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='yap' AND BENCH='j1axy')
		YAP
		ON YAP.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='sqlite3' AND BENCH='j1axy')
		SQLITE
		ON SQLITE.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='psql' AND BENCH='j1axy')
		PSQL
		ON PSQL.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='mariadb' AND BENCH='j1axy')
		MARIA
		ON MARIA.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='souffle' AND BENCH='j1axy')
		SOUFFLE
		ON SOUFFLE.FILE_ID = BAM.FILE_ID
	JOIN INPUT_FILE F
		ON BAM.FILE_ID = F.FILE_ID
ORDER BY F.SEQ_NO;


-- ============================================================================
-- Join1 a(X,Y) Results (Comparison with BAM on REAL Time, Only Factors):
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

-- It is a projection of J1AXY_REAL that shows only the factors
-- compared to BAM.
-- This makes the output rows a little smaller.

CREATE VIEW J1AXY_REAL_FACTORS AS
SELECT	FILE_ID, BAM_REAL,
	XSB_F, YAP_F, SQLITE_F, PSQL_F, MARIA_F, SOUFFLE_F
FROM	J1AXY_REAL
ORDER BY SEQ_NO;

-- ============================================================================
-- Join1 a(X,Y) Results (Comparison with BAM on REAL Time) - LaTeX Output:
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

CREATE VIEW J1AXY_REAL_LATEX AS
SELECT	FILE_ID,
	RPAD(REPLACE(FILE_ID, '_', '\_'), 12) || '&' ||
	TO_CHAR(BAM_REAL, '9990.999') || '&' ||
	(CASE WHEN XSB_F IS NULL THEN '      '
		ELSE TO_CHAR(XSB_F, '990.9') END) || '&' ||
	(CASE WHEN YAP_F IS NULL THEN '      '
		ELSE TO_CHAR(YAP_F, '990.9') END) || '&' ||
	(CASE WHEN SQLITE_F IS NULL THEN '      '
		ELSE TO_CHAR(SQLITE_F, '990.9') END) || '&' ||
	(CASE WHEN PSQL_F IS NULL THEN '      '
		ELSE TO_CHAR(PSQL_F, '990.9') END) || '&' ||
	(CASE WHEN MARIA_F IS NULL THEN '      '
		ELSE TO_CHAR(MARIA_F, '990.9') END) || '&' ||
	(CASE WHEN SOUFFLE_F IS NULL THEN '      '
		ELSE TO_CHAR(SOUFFLE_F, '990.9') END) || '\\'
	AS LATEX
FROM	J1AXY_REAL
ORDER BY SEQ_NO;


-- ============================================================================
-- Join1 a(X,Y) Benchmark Results (Comparison on REAL Time) - CSV Format:
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

-- This does not include factors compared with BAM,
-- but it uses BAM to start the outer join,
-- therefore only input files measured under BAM are displayed.

CREATE VIEW J1AXY_REAL_CSV AS
SELECT -1 AS SEQ_NO, NULL AS FILE_ID,
	'"Input","XSB","BAM","YAP","SQLite","PostgreSQL","MariaDB","Souffle"'
	AS CSV
FROM    DUMMY_TAB
UNION ALL
SELECT	SEQ_NO, FILE_ID,
		'"' || FILE_ID || '"' || ',' ||
		(CASE WHEN XSB_REAL IS NULL THEN ''
			ELSE TO_CHAR(XSB_REAL,'FM9999990.999') END) || ',' ||
		(CASE WHEN BAM_REAL IS NULL THEN ''
			ELSE TO_CHAR(BAM_REAL,'FM9999990.999') END) || ',' ||
		(CASE WHEN YAP_REAL IS NULL THEN ''
			ELSE TO_CHAR(YAP_REAL,'FM9999990.999') END) || ',' ||
		(CASE WHEN SQLITE_REAL IS NULL THEN ''
			ELSE TO_CHAR(SQLITE_REAL,'FM9999990.999') END) || ',' ||
		(CASE WHEN PSQL_REAL IS NULL THEN ''
			ELSE TO_CHAR(PSQL_REAL,'FM9999990.999') END) || ',' ||
		(CASE WHEN MARIA_REAL IS NULL THEN ''
			ELSE TO_CHAR(MARIA_REAL,'FM9999990.999') END) || ',' ||
		(CASE WHEN SOUFFLE_REAL IS NULL THEN ''
			ELSE TO_CHAR(SOUFFLE_REAL,'FM9999990.999') END)
		AS CSV
FROM	J1AXY_REAL
ORDER BY SEQ_NO;


-- ============================================================================
-- Join1 a(X,Y) Benchmark Results (Comparison with BAM on Memory):
-- ============================================================================

-- This looks only at the standard program version,
-- best implementation, on the standard machine.

CREATE VIEW J1AXY_MEM AS
SELECT	BAM.FILE_ID,
	BAM.MEM_MB AS BAM_MEM,
	XSB.MEM_MB AS XSB_MEM,
	(CASE WHEN BAM.MEM_MB=0 THEN NULL
		ELSE ROUND(XSB.MEM_MB/BAM.MEM_MB,1) END)
		AS XSB_F,
	YAP.MEM_MB AS YAP_MEM,
	(CASE WHEN BAM.MEM_MB=0 THEN NULL
		ELSE ROUND(YAP.MEM_MB/BAM.MEM_MB,1) END)
		AS YAP_F,
	SOUFFLE.MEM_MB AS SOUFFLE_MEM,
	(CASE WHEN BAM.MEM_MB=0 THEN NULL
		ELSE ROUND(SOUFFLE.MEM_MB/BAM.MEM_MB,1) END)
		AS SOUFFLE_F,
	SQLITE.MEM_MB AS SQLITE_MEM,
	(CASE WHEN BAM.MEM_MB=0 THEN NULL
		ELSE ROUND(SQLITE.MEM_MB/BAM.MEM_MB,1) END)
		AS SQLITE_F
FROM	(SELECT * FROM BEST_RESULT WHERE SYS='bam'AND BENCH='j1axy')
		BAM
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='xsb' AND BENCH='j1axy')
		XSB
		ON XSB.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='yap' AND BENCH='j1axy')
		YAP
		ON YAP.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='souffle' AND BENCH='j1axy')
		SOUFFLE
		ON SOUFFLE.FILE_ID = BAM.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='sqlite3' AND BENCH='j1axy')
		SQLITE
		ON SQLITE.FILE_ID = BAM.FILE_ID
	JOIN INPUT_FILE F
		ON BAM.FILE_ID = F.FILE_ID
ORDER BY F.SEQ_NO;


-- ############################################################################
-- Benchmark Results for Join1 a(X,Y) - Comparison with XSB:
-- ############################################################################


-- ============================================================================
-- Join1 a(X,Y) Benchmark Results (Comparison with XSB on REAL Time):
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

-- This version contains the runtime factors compared with XSB
-- and rounds the factors to two decimal places after the decimal point.
-- Otherwise it is identical to J1AXY_REAL (which compares with BAM).

CREATE VIEW J1AXY_REAL_XSB AS
SELECT	XSB.FILE_ID,
        F.SEQ_NO,
	XSB.REAL_T AS XSB_REAL,
	BAM.REAL_T AS BAM_REAL,
	(CASE WHEN XSB.REAL_T=0 THEN NULL
		ELSE ROUND(BAM.REAL_T/XSB.REAL_T,2) END)
		AS BAM_F,
	YAP.REAL_T AS YAP_REAL,
	(CASE WHEN XSB.REAL_T=0 THEN NULL
		ELSE ROUND(YAP.REAL_T/XSB.REAL_T,2) END)
		AS YAP_F,
	SQLITE.REAL_T AS SQLITE_REAL,
	(CASE WHEN XSB.REAL_T=0 THEN NULL
		ELSE ROUND(SQLITE.REAL_T/XSB.REAL_T,2) END)
		AS SQLITE_F,
	PSQL.REAL_T AS PSQL_REAL,
	(CASE WHEN XSB.REAL_T=0 THEN NULL
		ELSE ROUND(PSQL.REAL_T/XSB.REAL_T,2) END)
		AS PSQL_F,
	MARIA.REAL_T AS MARIA_REAL,
	(CASE WHEN XSB.REAL_T=0 THEN NULL
		ELSE ROUND(MARIA.REAL_T/XSB.REAL_T,2) END)
		AS MARIA_F,
	SOUFFLE.REAL_T AS SOUFFLE_REAL,
	(CASE WHEN XSB.REAL_T=0 THEN NULL
		ELSE ROUND(SOUFFLE.REAL_T/XSB.REAL_T,2) END)
		AS SOUFFLE_F
FROM	(SELECT * FROM BEST_RESULT WHERE SYS='xsb' AND BENCH='j1axy')
		XSB
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='bam' AND BENCH='j1axy')
		BAM
		ON BAM.FILE_ID = XSB.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='yap' AND BENCH='j1axy')
		YAP
		ON YAP.FILE_ID = XSB.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='sqlite3' AND BENCH='j1axy')
		SQLITE
		ON SQLITE.FILE_ID = XSB.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='psql' AND BENCH='j1axy')
		PSQL
		ON PSQL.FILE_ID = XSB.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='mariadb' AND BENCH='j1axy')
		MARIA
		ON MARIA.FILE_ID = XSB.FILE_ID
	LEFT JOIN
	(SELECT * FROM BEST_RESULT WHERE SYS='souffle' AND BENCH='j1axy')
		SOUFFLE
		ON SOUFFLE.FILE_ID = XSB.FILE_ID
	JOIN INPUT_FILE F
		ON XSB.FILE_ID = F.FILE_ID
ORDER BY F.SEQ_NO;

-- ============================================================================
-- Join1 a(X,Y) Results (Comparison with XSB on REAL Time, Only Factors):
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

-- It is a projection of J1AXY_REAL that shows only the factors
-- compared to XSB.
-- This makes the output rows a little smaller.

CREATE VIEW J1AXY_REAL_XSB_FACTORS AS
SELECT	FILE_ID, XSB_REAL,
	BAM_F, YAP_F, SQLITE_F, PSQL_F, MARIA_F, SOUFFLE_F
FROM	J1AXY_REAL_XSB
ORDER BY SEQ_NO;


-- ============================================================================
-- Join1 a(X,Y) Results (Comparison with XSB on REAL Time) - LaTeX Output:
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

CREATE VIEW J1AXY_REAL_XSB_LATEX AS
SELECT	FILE_ID,
	RPAD(REPLACE(FILE_ID, '_', '\_'), 10) || '&' ||
	TO_CHAR(XSB_REAL, '9990.999') || '&' ||
	(CASE WHEN BAM_F IS NULL     THEN '       '
		ELSE TO_CHAR(BAM_F, '990.99') END) || '&' ||
	(CASE WHEN YAP_F IS NULL     THEN '       '
		ELSE TO_CHAR(YAP_F, '990.99') END) || '&' ||
	(CASE WHEN SQLITE_F IS NULL  THEN '       '
		ELSE TO_CHAR(SQLITE_F, '990.99') END) || '&' ||
	(CASE WHEN PSQL_F IS NULL    THEN '       '
		ELSE TO_CHAR(PSQL_F, '990.99') END) || '&' ||
	(CASE WHEN MARIA_F IS NULL   THEN '       '
		ELSE TO_CHAR(MARIA_F, '990.99') END) || '&' ||
	(CASE WHEN SOUFFLE_F IS NULL THEN '       '
		ELSE TO_CHAR(SOUFFLE_F, '990.99') END) || '\\'
	AS LATEX
FROM	J1AXY_REAL_XSB
ORDER BY SEQ_NO;


-- ============================================================================
-- Join1 a(X,Y) Results (Comparison with XSB on REAL Time) - HTML Output:
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

CREATE VIEW J1AXY_REAL_XSB_HTML AS
SELECT -2 AS SEQ_NO, NULL AS FILE_ID,
	'<table>' AS HTML
FROM    DUMMY_TAB
UNION ALL
SELECT -1 AS SEQ_NO, NULL AS FILE_ID,
	'<tr>' ||
	     '<th class="colInput">'   || 'Input'          || '</th>' || '
	' || '<th class="colXSBTime">' || 'XSB (s)'        || '</th>' || '
	' || '<th class="colBAM"    >' || 'BAM'            || '</th>' || '
	' || '<th class="colYAP"    >' || 'YAP'            || '</th>' || '
	' || '<th class="colSQLite" >' || 'SQLite'         || '</th>' || '
	' || '<th class="colPSQL"   >' || 'PostgreSQL'     || '</th>' || '
	' || '<th class="colMaria"  >' || 'MariaDB'        || '</th>' || '
	' || '<th class="colSouffle">' || 'Souffl&eacute;' || '</th>' || '
	' || '</tr>'
	AS HTML
FROM    DUMMY_TAB
UNION ALL
SELECT	SEQ_NO, FILE_ID,
	'<tr>' ||
	'<td class="colInput">' || FILE_ID || '</td>' || '
	' || '<td class="colXSBTime">' || TO_CHAR(XSB_REAL, '9990.999') ||
		'&nbsp;s' || '</td>' || '
	' || '<td class="colBAM"    >' ||
		(CASE WHEN BAM_F IS NULL     THEN '&nbsp; '
			ELSE TO_CHAR(BAM_F,    '9990.99') END) || '</td>' || '
	' || '<td class="colYAP"    >' ||
		(CASE WHEN YAP_F IS NULL     THEN '&nbsp; '
			ELSE TO_CHAR(YAP_F,    '9990.99') END) || '</td>' || '
	' || '<td class="colSQLite" >' ||
		(CASE WHEN SQLITE_F IS NULL  THEN '&nbsp; '
			ELSE TO_CHAR(SQLITE_F, '9990.99') END) || '</td>' || '
	' || '<td class="colPSQL"   >' ||
		(CASE WHEN PSQL_F IS NULL    THEN '&nbsp; '
			ELSE TO_CHAR(PSQL_F,   '9990.99') END) || '</td>' || '
	' || '<td class="colMaria"  >' ||
		(CASE WHEN MARIA_F IS NULL   THEN '&nbsp; '
			ELSE TO_CHAR(MARIA_F,  '9990.99') END) || '</td>' || '
	' || '<td class="colSouffle">' ||
		(CASE WHEN SOUFFLE_F IS NULL THEN '&nbsp; '
			ELSE TO_CHAR(SOUFFLE_F,'9990.99') END) || '</td>' || '
	' || '</tr>'
	AS HTML
FROM	J1AXY_REAL_XSB
UNION ALL
SELECT 1000000 AS SEQ_NO, NULL AS FILE_ID,
	'</table>' AS HTML
FROM    DUMMY_TAB
ORDER BY SEQ_NO;


-- ############################################################################
-- Join1 Input Data:
-- ############################################################################


-- ============================================================================
-- Join1 Input Data as HTML:
-- ============================================================================

CREATE VIEW INPUT_JOIN1_HTML AS
SELECT -2 AS SEQ_NO, NULL AS FILE_ID,
	'<table>' AS HTML
FROM    DUMMY_TAB
UNION ALL
SELECT -1 AS SEQ_NO, NULL AS FILE_ID,
	'<tr>' ||
	'<th class="colInput">' || 'Input'          || '</th>' || '
	' || '<th class="colNodes"   >' || 'Nodes'           || '</th>' || '
	' || '<th class="colD1Edges" >' || 'd1&nbsp;Edges'   || '</th>' || '
	' || '<th class="colD2Edges" >' || 'd2&nbsp;Edges'   || '</th>' || '
	' || '<th class="colC2Edges" >' || 'c2&nbsp;Edges'   || '</th>' || '
	' || '<th class="colC3Edges" >' || 'c3&nbsp;Edges'   || '</th>' || '
	' || '<th class="colC4Edges" >' || 'c4&nbsp;Edges'   || '</th>' || '
	' || '<th class="colASize"   >' || 'a&nbsp;Size.'    || '</th>' || '
	' || '<th class="colB1Size"  >' || 'b1&nbsp;Size.'   || '</th>' || '
	' || '<th class="colB2Size"  >' || 'b2&nbsp;Size.'   || '</th>' || '
	' || '<th class="colC1Size"  >' || 'c1&nbsp;Size.'   || '</th>' || '
	' || '<th class="colRuleInst">' || 'Rule&nbsp;Inst.' || '</th>' || '
	' || '</tr>'
	AS HTML
FROM    DUMMY_TAB
UNION ALL
SELECT	F.SEQ_NO, F.FILE_ID,
	'<tr>' ||
	'<td class="colInput">' ||
		'<a href="data_p/' || F.FILENAME || '.P"
		>' || F.FILE_ID || '</a>' || '</td>' || '
	' || '<td class="colNodes"   >' || NUM_NODES || '</td>' || '
	' || '<td class="colD1Edges" >' || D1_SIZE   || '</td>' || '
	' || '<td class="colD2Edges" >' || D2_SIZE   || '</td>' || '
	' || '<td class="colC2Edges" >' || C2_SIZE   || '</td>' || '
	' || '<td class="colC3Edges" >' || C3_SIZE   || '</td>' || '
	' || '<td class="colC4Edges" >' || C4_SIZE   || '</td>' || '
	' || '<td class="colASize"   >' || A_SIZE    || '</td>' || '
	' || '<td class="colB1Size"  >' || B1_SIZE   || '</td>' || '
	' || '<td class="colB2Size"  >' || B2_SIZE   || '</td>' || '
	' || '<td class="colC1Size"  >' || C1_SIZE   || '</td>' || '
	' || '<td class="colRuleInst">' || A_INST+B1_INST+B2_INST+C1_INST
	                                             || '</td>' || '
	' || '</tr>'
	AS HTML
FROM	INPUT_JOIN1 J, INPUT_FILE F
WHERE   J.FILE_ID = F.FILE_ID
UNION ALL
SELECT 1000000 AS SEQ_NO, NULL AS FILE_ID,
	'</table>' AS HTML
FROM    DUMMY_TAB
ORDER BY SEQ_NO;


-- ############################################################################
-- Plot Data (Runtime vs. Cost):
-- ############################################################################


-- ============================================================================
-- Plot of Real Time vs. Cost for Join1 a(X,Y) Benchmark:
-- ============================================================================

-- This looks only at the runtimes of the standard program version,
-- best implementation, on the standard machine.

CREATE VIEW J1AXY_PLOT_REAL AS
SELECT	R.SYS,
	R.FILE_ID,
	F.SEQ_NO AS NO,
	(C.A_INST+C.B1_INST+C.B2_INST+C.C1_INST) AS COST,
	R.REAL_T,
	'"' || R.FILE_ID || '","' ||
		(C.A_INST+C.B1_INST+C.B2_INST+C.C1_INST) || '","'
		|| R.REAL_T || '"'
		AS CSV,
	R.FILE_ID || '	' ||
		(C.A_INST+C.B1_INST+C.B2_INST+C.C1_INST) || '	' || R.REAL_T
		AS TSV
FROM	RESULT R, INPUT_FILE F, INPUT_JOIN1 C, BENCH_IMPL I
WHERE   R.BENCH = 'j1axy' AND R.FILE_ID = F.FILE_ID AND R.FILE_ID = C.FILE_ID
AND	I.BENCH = R.BENCH AND I.IMPL = R.IMPL AND I.SYS = R.SYS
AND	I.STATUS = 'B'
UNION
SELECT  DISTINCT P.SYS, '', -1, 0 AS COST, 0 AS REAL_T,
	'"df","cost","tavg"' as CSV,
	'df	cost	tavg' as TSV
FROM	TEST_SYS P
WHERE	EXISTS(SELECT * FROM RESULT R
		WHERE R.BENCH = 'j1axy' AND R.SYS = P.SYS)
ORDER BY SYS, NO;

