-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/v_maria.sql
-- Purpose:	Benchmark DB: Views to Support Result Analysis for MariaDB
-- Last Change:	04.03.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2018-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- Benchmark Results for MariaDB (Current Ver., Standard Machine, No Output):
-- ============================================================================

CREATE VIEW MARIA AS
SELECT BENCH,
	IMPL,
	FILE_ID,
	-- LOAD_T,
	-- EXEC_T,
	-- TOTAL_T,
	CPU_T,
	REAL_T,
	MEM_MB
FROM RESULT
WHERE SYS = 'mariadb';

-- ============================================================================
-- Compare Storage Managers for MariaDB:
-- ============================================================================

CREATE VIEW MARIA_COMPARE AS
SELECT INNO.BENCH,
	INNO.FILE_ID,
        F.LINES,
	INNO.REAL_T AS INNO_REAL_T,
	MEM.REAL_T AS MEM_REAL_T,
	CASE WHEN INNO.REAL_T > 0 THEN
                ROUND((INNO.REAL_T-MEM.REAL_T)*100/INNO.REAL_T)
                ELSE NULL END AS MEM_BETTER_PCT,
	CASE WHEN INNO.REAL_T < MEM.REAL_T THEN 'Y' ELSE ' ' END AS INNO_BETTER
FROM MARIA INNO, MARIA MEM, INPUT_FILE F
WHERE INNO.BENCH = MEM.BENCH AND INNO.FILE_ID = MEM.FILE_ID AND
        INNO.IMPL = 'i' AND MEM.IMPL = 'm' AND
	F.FILE_ID = INNO.FILE_ID
ORDER BY INNO.BENCH, F.SEQ_NO;

