-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/v_scripts.sql
-- Purpose:	Benchmark DB: Views Supporting Benchmark Execution Scripts
-- Last Change:	04.03.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2018-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ############################################################################
-- Support for Benchmark Execution Scripts (To Generate Parts of Scripts):
-- ############################################################################

-- ============================================================================
-- BENCH_FILE_LIST: For RUN_BENCH Scripts
-- ============================================================================

-- This produces the benchmark file list for use in the RUN_BENCH scripts.
-- The result is to be used in a "case" switch in the bash script.

CREATE VIEW BENCH_FILE_LIST AS
SELECT '' AS FILE_ID, '' AS ITYPE, T.SEQ_NO AS TNO, -2 AS FNO,
	'' AS DATA_P,
	'' AS DATA_TSV
FROM INPUT_TYPE T
UNION ALL
SELECT '' AS FILE_ID, '' AS ITYPE, T.SEQ_NO AS TNO, -1 AS FNO,
	'    ' || '# ' || T.HEADLINE || ':' AS DATA_P,
	'    ' || '# ' || T.HEADLINE || ':' AS DATA_TSV
FROM INPUT_TYPE T
UNION ALL
SELECT F.FILE_ID, F.ITYPE, T.SEQ_NO AS TNO, F.SEQ_NO AS FNO,
	'    ' || RPAD((F.FILE_ID || ')'), 11) ||
	' FTYPE=' || RPAD((F.ITYPE || ';'), 11) ||
	'FILE=../data_p/' || F.FILENAME || '.P' || ' ;;' AS DATA_P,
	'    ' || RPAD((F.FILE_ID || ')'), 9) ||
	' FTYPE=' || RPAD((F.ITYPE || ';'), 9) ||
	'FILE=../data_tsv/' || F.FILENAME || '.tsv' || ' ;;' AS DATA_TSV
FROM INPUT_FILE F, INPUT_TYPE T
WHERE F.ITYPE = T.ITYPE
ORDER BY TNO, FNO;

-- Note that RPAD cuts off strings that are too long (in PostgreSQL).
-- This is only safe because FILE_ID is declared as VARCHAR(10)
-- and ITYPE as VARCHAR(8).

-- ============================================================================
-- TC_FILE_IDs: For RUN_BENCH_LIST Scripts
-- ============================================================================

CREATE VIEW TC_FILE_IDS AS
SELECT -1 AS SEQ_NO, ' ' AS GTYPE,
	'TC_FILE_IDS="\' AS FILE_IDS
UNION ALL
SELECT T.SEQ_NO, T.GTYPE,
	CHR(9) || STRING_AGG(G.FILE_ID, ' ') || ' ' || '\' AS FILE_IDS
FROM INPUT_GRAPH G, GRAPH_TYPE T
WHERE G.GTYPE = T.GTYPE
GROUP BY T.SEQ_NO, T.GTYPE
UNION ALL
SELECT 1000000 AS SEQ_NO, ' ' AS GTYPE,
	CHR(9) || '"' AS FILE_IDS
ORDER BY SEQ_NO;

-- CHR(9) is a TAB character.
-- PostgreSQL ignores literal TAB characters on input.

-- For MySQL, replace
--	STRING_AGG(G.FILE_ID, ' ')
-- by
--	GROUP_CONCAT((G.FILE_ID SEPARATOR ' '))

