-- ============================================================================
-- Project:	ddbench - Deductive System and Database Benchmarks
-- Filename:	db/xsb.sql
-- Purpose:	Database for Benchmark Runs: Data for XSB System
-- Last Change:	06.02.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- System to be Tested/Compared:
-- ============================================================================

-- INSERT INTO TEST_SYS VALUES (
--	SYS, SEQ_NO, FULL_NAME, STYPE,
--	URL,
--	REMARK);

INSERT INTO TEST_SYS VALUES (
	'xsb', 10, 'XSB', 'Prolog',
	'http://xsb.sourceforge.net/',
	NULL);


-- ============================================================================
-- Versions of the Test System:
-- ============================================================================

-- INSERT INTO SYS_VER VALUES (
--	SYS, VER, VER_ADDTEXT, VER_DATE,
--	REMARK);

INSERT INTO SYS_VER VALUES (
	'xsb', '3.7.', ' (Clan MacGregor)', '2016-07-06',
	NULL);

INSERT INTO SYS_VER VALUES (
	'xsb', '3.8.0', ' (Three-Buck Chuck)', '2017-10-28',
	NULL);


-- ============================================================================
-- Installed Program Versions on Machines:
-- ============================================================================

-- INSERT INTO SYS_INSTALL VALUES (
-- 	SYS, VER, MACHINE, INST_NO,
-- 	COMPILER,
-- 	STATUS, -- 'C': current version, 'P' previous, 'A' alternate, ' ' other
-- 	REMARK);

-- Installations on main test machine:

INSERT INTO SYS_INSTALL VALUES (
	'xsb', '3.7.', 'dbs1', 1,
	'',
	'C',
	'x86_64-unknown-linux-gnu 64 bits; ' ||
		'mode: optimal; engine: slg-wam; scheduling: local');

INSERT INTO SYS_INSTALL VALUES (
	'xsb', '3.8.0', 'dbs1', 2,
	'',
	'C',
	'x86_64-unknown-linux-gnu 64 bits; ' ||
		'mode: optimal; engine: slg-wam; scheduling: local');

-- Installations on development machine:

INSERT INTO SYS_INSTALL VALUES (
	'xsb', '3.8.0', 'bach', 2,
	'',
	'C',
	'x86_64-unknown-linux-gnu 64 bits; ' ||
		'mode: optimal; engine: slg-wam; scheduling: local');

-- Installations on old test machine:

INSERT INTO SYS_INSTALL VALUES (
	'xsb', '3.7.', 'dbs0', 1,
	'',
	'C',
	'x86_64-unknown-linux-gnu 64 bits; ' ||
		'mode: optimal; engine: slg-wam; scheduling: local');

INSERT INTO SYS_INSTALL VALUES (
	'xsb', '3.8.0', 'dbs0', 2,
	'',
	'C',
	'x86_64-unknown-linux-gnu 64 bits; ' ||
		'mode: optimal; engine: slg-wam; scheduling: local');


-- ============================================================================
-- Benchmark Implementations:
-- ============================================================================

-- INSERT INTO BENCH_IMPL VALUES (
-- 	SYS, BENCH, IMPL, STATUS, -- STATUS='B': best, 'A' alternate, ' ' other
-- 	DESCRIPTION);

-- ----------------------------------------------------------------------------
-- DBLP Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dyn', 'A',
	'load_dyn, no index');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dync', 'A',
	'load_dync, no index');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dynin', 'A',
	'load_dyn, index on col 1+2');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dyncin', 'B',
	'load_dync, index on col 1+2');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dyntr', 'A',
	'load_dyn, trie index');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dynctr', 'A',
	'load_dync, trie index');

-- ----------------------------------------------------------------------------
-- Join1 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axyd', 'none', 'B',
	'Join1 with duplicates, a(X,Y) [V0: no tabling]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'a', ' ',
	'Join1, a(X,Y) [V1: only a tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'all', ' ',
	'Join1, a(X,Y) [V2: all derived preds tabled (subsumptive)]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'allv', 'B',
	'Join1, a(X,Y) [V4: all derived preds tabled, variant tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'alli', ' ',
	'Join1, a(X,Y) [V4: all derived preds tabled, with indexes]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'allt', 'A',
	'Join1, a(X,Y) [V5: all derived preds tabled, with trie index]');

-- ----------------------------------------------------------------------------
-- TCFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', 'dyn', ' ',
	'tc(X,Y) [V1: load_dyn, trie-index for par, subsumptive tabling]');

-- INSERT INTO BENCH_IMPL VALUES (
--	'xsb', 'tcff', 'dync', 'B',
--	'tc(X,Y) [V2: load_dync, trie-index for par]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', '', ' ',
	'tc(X,Y) [V2: load_dync, trie-index for par - measured by MW]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', '2', 'B',
	'tc(X,Y) [V2: load_dync/a, trie-index for par, subsumptive tabling]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', '3', ' ',
	'tc(X,Y) [V3: load_dync/a, index on 2,1 for par, subsumptive tabling]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', '4', ' ',
	'tc(X,Y) [V4: load_dync/a, index on 2,1 for par, variant tabling]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', '5', ' ',
	'tc(X,Y) [V5: load_dync/a, index on 1,2 for par, subsumptive tabling]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', '6', ' ',
	'tc(X,Y) [V6: load_dync/a, index on 1,2 for par, variant tabling]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', '7', ' ',
	'tc(X,Y) [V7: load_dync/z, index on 1 for par, subsumptive tabling]');

-- Note: tcff_3 and tcff_5 and in part tcff_7 write lots of messages
-- Potential performance problem in tsiOrderedInsert in tst_insert.c


-- ----------------------------------------------------------------------------
-- TCBF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcbf', 'dyn', ' ',
	'tc(1,X) [V1: load_dyn, trie-index for par]');

-- INSERT INTO BENCH_IMPL VALUES (
--	'xsb', 'tcbf',  'dync', 'B',
--	'tc(1,X) [V2: load_dync, trie-index for par]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcbf',  '', 'B',
	'tc(1,X) [V2: load_dync, trie-index for par]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcbfs', 'slddc', 'B',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index]');

-- ----------------------------------------------------------------------------
-- TCFB Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcfb',  '', 'B',
	'tc(X,1) [unknown implementation]');

-- ----------------------------------------------------------------------------
-- SGFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  '1', ' ',
	'sg(X,Y) [standard tabling, load_dyn, index on par(1,2)]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  '2', ' ',
	'sg(X,Y) [standard tabling, load_dync, index on par(1,2)]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  '3', ' ',
	'sg(X,Y) [standard tabling, load_dyn, index on par(2)]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  '4', ' ',
	'sg(X,Y) [standard tabling, load_dync, index on par(2)]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  '5', ' ',
	'sg(X,Y) [standard tabling, load_dyn, index on par(2,1)]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  '6', ' ',
	'sg(X,Y) [standard tabling, load_dync, index on par(2,1)]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  '7', ' ',
	'sg(X,Y) [standard tabling, load_dyn, trie index on par]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  '8', ' ',
	'sg(X,Y) [standard tabling, load_dync, trie index on par]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  '9', 'B',
	'sg(X,Y) [subsumptive tabling, load_dync, index on par(2,1)]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'sgff',  'A', ' ',
	'sg(X,Y) [subsumptive tabling, load_dync, trie index on par]');


-- ----------------------------------------------------------------------------
-- Wine Ontology Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'wine', 'is', 'B',
	'wine ontology [V1: load_dync, subsumptive tabling, std. indexes]');


-- ----------------------------------------------------------------------------
-- Win-WFS Benchmark (Unstratified Negation):
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'win', '1', 'B',
	'win WFS [V1: load_dync, subsumptive tabling, trie index]');

