-- ============================================================================
-- Project:	ddbench - Deductive System and Database Benchmarks
-- Filename:	db/yap.sql
-- Purpose:	Database for Benchmark Runs: Data for the YAP System
-- Last Change:	05.03.2019
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- System to be Tested/Compared:
-- ============================================================================

-- INSERT INTO TEST_SYS VALUES (
--	SYS, SEQ_NO, FULL_NAME, STYPE,
--	URL,
--	REMARK);

INSERT INTO TEST_SYS VALUES (
	'yap', 11, 'YAProlog', 'Prolog',
	'https://www.dcc.fc.up.pt/~vsc/Yap/',
	NULL);


-- ============================================================================
-- Versions of the Test System:
-- ============================================================================

-- INSERT INTO SYS_VER VALUES (
--	SYS, VER, VER_ADDTEXT, VER_DATE,
--	REMARK);

INSERT INTO SYS_VER VALUES (
	'yap', '6.2.2', ' (x86_64-linux)', '2011-10-21',
	NULL);

INSERT INTO SYS_VER VALUES (
	'yap', '6.3.3', ' (x86_64-linux)', '2013-01-20',
	NULL);


-- ============================================================================
-- Installed Program Versions on Machines:
-- ============================================================================

-- INSERT INTO SYS_INSTALL VALUES (
-- 	SYS, VER, MACHINE, INST_NO,
-- 	COMPILER,
-- 	STATUS, -- 'C': current version, 'P' previous, 'A' alternate, ' ' other
-- 	REMARK);

-- Installations on main test machine:

INSERT INTO SYS_INSTALL VALUES (
	'yap', '6.2.2', 'dbs1', 1,
	'',
	'C',
	NULL);

-- Installations on development machine:

INSERT INTO SYS_INSTALL VALUES (
	'yap', '6.3.3', 'bach', 2,
	'',
	'C',
	NULL);

-- Installations on old test machine:

INSERT INTO SYS_INSTALL VALUES (
	'yap', '6.2.2', 'dbs0', 1,
	'',
	'C',
	NULL);


-- ============================================================================
-- Benchmark Implementations:
-- ============================================================================

-- INSERT INTO BENCH_IMPL VALUES (
-- 	SYS, BENCH, IMPL, STATUS, -- STATUS='B': best, 'A' alternate, ' ' other
-- 	DESCRIPTION);

-- ----------------------------------------------------------------------------
-- DBLP Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'dblp', '1', 'B',
	'DBLP Benchmark');

-- ----------------------------------------------------------------------------
-- Join1 Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'j1axyd', 'none', 'B',
	'Join1 with duplicates, a(X,Y) [V0: no tabling]');

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'j1axy', 'a', ' ',
	'Join1, a(X,Y) [V1: only a tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'j1axy', 'all', 'B',
	'Join1, a(X,Y) [V2: all derived preds tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'j1axy', 'unt', 'B',
	'Join1, a(X,Y) [Measurement by Mario Wenzel]');
	
INSERT INTO BENCH_IMPL VALUES (
	'yap', 'j1axyd', 'unt', ' ',
	'Join1, a(X,Y) [V0: no tabling]');

-- ----------------------------------------------------------------------------
-- TCFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'tcff', 'tab', 'B',
	'tc(X,Y) [V1: tc tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'tcff', '', 'B',
	'tc(X,Y) [Implementation by Mario Wenzel]');


-- ----------------------------------------------------------------------------
-- TCBF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'tcbf', 'tab', 'B',
	'tc(1,X) [V1: tc tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'tcbfs', 'sldm', 'B',
	'tc(1,X) [V2: with SLDMagic, all preds tabled]');


-- ----------------------------------------------------------------------------
-- TCFB Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'tcfb', '', 'B',
	'tc(X,1) [V1: tc tabled]');

-- ----------------------------------------------------------------------------
-- SGFF Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'sgff', '1', 'B',
	'sg(X,Y) [V1: sg tabled]');

-- ----------------------------------------------------------------------------
-- Wine Ontology Benchmark:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'wine', 'tab', 'B',
	'wine ontology [V1: table 225 derived preds, reorder body lits]');

