% tc_iter(X, Y, Iter).
:- dynamic par/2.
:- dynamic tc_iter/3.
:- dynamic tc_size/1.

main(DataFile) :-
	retractall(par(_,_)),
	retractall(tc_iter(_,_,_)),
	retractall(tc_size(_)),
	assert(tc_size(0)),
	write('Loading data ...'),
	nl,
	statistics(walltime, [Real1|_]),
	statistics(cputime, CPU1),
	[DataFile],
	statistics(walltime, [Real2|_]),
	statistics(cputime, CPU2),
	nonrecursive,
	botup(2),
	statistics(walltime, [Real3|_]),
	statistics(cputime, CPU3),
	LoadRealTime is Real2 - Real1,
	LoadCPUTime is round((CPU2 - CPU1) * 1000),
	ComputeRealTime is Real3 - Real2,
	ComputeCPUTime is round((CPU3 - CPU2) * 1000),
	TotalRealTime is Real3 - Real1,
	TotalCPUTime is round((CPU3 - CPU1) * 1000),
	write('Load Real Time: '),
	write(LoadRealTime),
	write(' ms'),
	nl,
	write('Load CPU  Time: '),
	write(LoadCPUTime),
	write(' ms'),
	nl,
	write('Compute Real Time: '),
	write(ComputeRealTime),
	write(' ms'),
	nl,
	write('Compute CPU  Time: '),
	write(ComputeCPUTime),
	write(' ms'),
	nl,
	write('Total Real Time: '),
	write(TotalRealTime),
	write(' ms'),
	nl,
	write('Total CPU  Time: '),
	write(TotalCPUTime),
	write(' ms'),
	nl.

%------------------------------------------------------------------------------
% Apply nonrecursive rule:
%------------------------------------------------------------------------------

nonrecursive :-
	write('Iteration 1 (nonrecursive rule).'),
	nl,
	par(X, Y),
	insert_tc_iter(X, Y, 1),
	fail.

nonrecursive.

%------------------------------------------------------------------------------
% Insert a Fact:
%------------------------------------------------------------------------------

insert_tc_iter(X, Y, _Iter) :-
	tc_iter(X, Y, _Old),
	!.

insert_tc_iter(X, Y, Iter) :-
	assert(tc_iter(X, Y, Iter)),
	tc_size(Size),
	retract(tc_size(Size)),
	NewSize is Size + 1,
	assert(tc_size(NewSize)).

%------------------------------------------------------------------------------
% Do Next Iteration:
%------------------------------------------------------------------------------

do_iter(Iter) :-
	PrevIter is Iter - 1,
	par(X, Y),
	tc_iter(Y, Z, PrevIter),
	insert_tc_iter(X, Z, Iter),
	fail.

do_iter(_).

%------------------------------------------------------------------------------
% Do Bottom-Up Evaluation:
%------------------------------------------------------------------------------

botup(Iter) :-
	PrevIter is Iter - 1,
	tc_iter(_, _, PrevIter),
	!,
	write('Iteration '),
	write(Iter),
	write(' (Number of Facts so far: '),
	tc_size(Size),
	write(Size),
	write(')'),
	nl,
	do_iter(Iter),
	NextIter is Iter+1,
	botup(NextIter).

botup(Iter) :-
	FinalIter is Iter - 2,
	write('Finished after '),
	write(FinalIter),
	write(' Iterations.'),
	nl,
	write('TC Size: '),
	tc_size(Size),
	write(Size),
	nl.

