\timing on

drop table if exists par;

create table par(x integer not null, y integer not null);

-- This improves loading time, but not query time (loading is anyway fast):
-- create temporary table par(x integer not null, y integer not null);
-- create unlogged table par(x integer not null, y integer not null);

-- This is significantly slower:
-- create table par(x numeric(4) not null, y numeric(4) not null);

\echo 'LOAD DATA'
\copy par from 'tc2_d1000_parsize50000_c.tsv';

-- I tried all these indexes, but they do not influence runtime
-- (although at least par_y and par_yx are used in the access plan):
-- create index par_x on par(x);
-- create index par_y on par(y);
-- create index par_xy on par(x,y);
-- create unique index par_yx on par(y,x);
create index par_yx on par(y,x);

-- This speeds up query execution time a bit (14s instead of 17s):
analyze par;

-- The EXPLAIN makes the query slower (16s instead of 14s):
-- EXPLAIN (ANALYZE on, VERBOSE on, BUFFERS on)
with recursive tc_tmp as
	(select par.x, par.y
	from   par
	union
	select par.x, tc_tmp.y
	from   par, tc_tmp
	where  par.y = tc_tmp.x)
select count(*) from tc_tmp;


-- Running the query again is only minimally faster
-- with recursive tc_tmp as
--	(select par.x, par.y
--	from   par
--	union
--	select par.x, tc_tmp.y
--	from   par, tc_tmp
--	where  par.y = tc_tmp.x)
-- select count(*) from tc_tmp;

