#!/bin/bash
cd "$(dirname "$0")"
cp vendor/*.js out/
cp vendor/*.css out/
[ -f out/style.css ] && rm out/style.css
cp out/bootstrap.min.css out/style.css
echo "/* custom style */" >> out/style.css
cat style.css >> out/style.css

TITLE="Benchmarks of Deductive Database Systems, Relational Databases, and Graph Databases"
MAKEPAGE=(pandoc -s -T "${TITLE}" -H common/js_include.html -t html5 -B common/nav.html --from markdown+raw_html --toc -c style.css -o)

# index.html
"${MAKEPAGE[@]}" out/index.html \
index/intro.md \
index/systems.md \
index/cost_measure.md \
index/instances.md \
index/tcff.md \
index/results.md tables/graph_data.html \
index/measurements.md tables/tcff_real_xsb.html index/tcff_vis.md \
index/sgff.md \
index/measurements.md tables/sgff_real_xsb.html index/sgff_vis.md \
index/join1.md \
index/measurements.md tables/j1axy_real_xsb.html \
index/footer.md

#db.html
"${MAKEPAGE[@]}" out/db.html \
db/db_doc.md

#xsb.html
"${MAKEPAGE[@]}" out/xsb.html \
systems/xsb/intro.md \
systems/xsb/tcff.md \
systems/xsb/sgff.md

#yap.html
"${MAKEPAGE[@]}" out/yap.html \
systems/yap/intro.md \
systems/yap/tcff.md \
systems/yap/sgff.md

#swipl.html
"${MAKEPAGE[@]}" out/swipl.html \
systems/swipl/intro.md \
systems/swipl/tcff.md

#sqlite.html
"${MAKEPAGE[@]}" out/sqlite.html \
systems/sqlite/intro.md \
systems/sqlite/tcff.md \
systems/sqlite/sgff.md

#mariadb.html
"${MAKEPAGE[@]}" out/mariadb.html \
systems/mariadb/intro.md \
systems/mariadb/tcff.md \
systems/mariadb/sgff.md

#psql.html
"${MAKEPAGE[@]}" out/psql.html \
systems/psql/intro.md \
systems/psql/tcff.md \
systems/psql/sgff.md

#neo4j.html
"${MAKEPAGE[@]}" out/neo4j.html \
systems/neo4j/intro.md \
systems/neo4j/tcff.md \
systems/neo4j/sgff.md

#jena.html
"${MAKEPAGE[@]}" out/jena.html \
systems/jena/intro.md \
systems/jena/tcff.md

#souffle.html
"${MAKEPAGE[@]}" out/souffle.html \
systems/souffle/intro.md \
systems/souffle/tcff.md \
systems/souffle/sgff.md

# make tables nice
sed -i -e 's/<table>/<table class="table table-striped table-bordered table-sm table-condensed">/g' out/*.html
sed -i -e 's/<table style="width:100%;">/<table class="table table-striped table-bordered table-sm table-condensed">/g' out/*.html

# copy tsv data
cp -r tsv out/

# date
DATE=`date +%F`
sed -i -e "s/{date}/${DATE}/g" out/*.html

#validate
(which html5validator &> /dev/null && \
html5validator out/*.html \\
) || true
