# Problem: JOIN1

The JOIN1 problem is a join of five relations where every join is its own
auxiliary predicate to facilitate (early) duplicate elimination.
The benchmark query is `a(X,Y)`.

```
a(X, Y)  :- t2(X, Z), t3(Z, Y).
t3(X, Y) :- c4(X, Z), c5(Z, Y).
t2(X, Y) :- t1(X, Z), c3(Z, Y).
t1(X, Y) :- c1(X, Z), c2(Z, Y).
```

A flat query without explicit duplicate elimination possibilities would be

```
a(X, Y)  :- c1(X, A), c2(A, B), c3(B, C), c4(C, D), c5(D, Y).
```

This query is also a part of the [OpenRuleBench](#references-and-related-work) suite.
OpenRuleBench also evaluates other queries. We will do that in the future as well.

<!-- * Datalog Systems
  * Benchmarked Systems
    * [Soufflé](souffle.html#sgff)
* Relational Database
  * Benchmarked Systems
    * [SQLite3](sqlite.html#sgff) (Disabled temporary files (forcing in-memory evaluation))
    * [MariaDB](mariadb.html#sgff) (`InnoDB` and `MEMORY` with `BTREE` and `HASH` index)
    * [PostgreSQL](psql.html#sgff)
* Prolog Systems
  * Benchmarked Systems
    * [xsb](xsb.html#sgff)
    * [YAProlog](yap.html#sgff)
  * We evaluate `a(_,_), fail.` to iterate over the whole relationship -->

## SQL Formulation

```
WITH
	t1 AS
	(
		SELECT DISTINCT c1.a, c2.b
		FROM c1, c2
		WHERE c1.b = c2.a
	),
	t2 AS
	(
		SELECT DISTINCT t1.a, c3.b
		FROM t1, c3
		WHERE t1.b = c3.a
	),
	t3 AS
	(
		SELECT DISTINCT c4.a, c5.b
		FROM c4, c5
		WHERE c4.b = c5.a
	),
	a AS
	(
		SELECT DISTINCT t2.a, t3.b
		FROM t2, t3
		WHERE t2.b = t3.a
	)
SELECT COUNT(*) FROM a;
```
