# Problem: Same Generation (sgff)

The SGFF problem is generating the "cousin" relationship of a directed graph.
Two nodes are in the same generation if both have direct predecessors that are in the same generation.
The resulting relationship is an equivalence relationship.
The output is potentially quadratic in the input size.

We use the [same input data as for the Same Generation Problem](#input-graphs).

```
sg(Y,Y) :- par(_, Y).
sg(X,Y) :- par(X,A), sg(A,B), par(Y,B).
```

* Datalog Systems
    * Benchmarked Systems
        * BAM abstract machine (push method)
        * [Soufflé](souffle.html#sgff)
* Relational Database
    * Benchmarked Systems
        * [SQLite3](sqlite.html#sgff) (Disabled temporary files (forcing in-memory evaluation))
        * [MariaDB](mariadb.html#sgff) (`InnoDB` and `MEMORY` with `BTREE` and `HASH` index)
        * [PostgreSQL](psql.html#sgff)
    * We used Recursive Common Table Expressions to express this query
    * We added an indexes on the second column of the base relation
* Prolog Systems
    * Benchmarked Systems
        * [xsb](xsb.html#sgff)
        * [YAProlog](yap.html#sgff)
    * Tabling needs to be enabled to ensure termination for cyclic input graphs
    * We evaluate `sg(_,_), fail.` to iterate over the whole relationship

The instances are generated using our [graphgen tool](https://gitlab.informatik.uni-halle.de/mwenzel/graphgen).

## SQL Formulation

```
WITH RECURSIVE sg(a,b) AS (
	SELECT par.b, par.b from par
	UNION
	SELECT p1.a, p2.a from sg JOIN par p1 ON p1.b = sg.a JOIN par p2 ON p2.b = sg.b
) SELECT Count(*) FROM sg;
```

with the table definition

```
CREATE TEMP TABLE par (
  a INT NOT NULL, b INT NOT NULL,
  CONSTRAINT par_pk PRIMARY KEY (a, b)
) WITHOUT ROWID;
CREATE INDEX par_fb ON par (b);
```
