# Problem: Transitive Closure (tcff)

The TCFF problem is generating a Transitive closure of a directed graph. The output
is potentially quadratic in the input size.

    tc(A, B) :- par(A, B).
    tc(A, B) :- par(A, X), tc(X, B).

* Datalog Systems
    * Benchmarked Systems
        * BAM abstract machine (push method)
        * [Soufflé](souffle.html#tcff)
* Relational Database
    * Benchmarked Systems
        * [SQLite3](sqlite.html#tcff) (Disabled temporary files (forcing in-memory evaluation))
        * [MariaDB](mariadb.html#tcff) (`InnoDB` and `MEMORY` with `BTREE` and `HASH` index)
        * [PostgreSQL](psql.html#tcff)
    * We used Recursive Common Table Expressions to express this query
    * We added an indexes on the second column of the base relation
* Prolog Systems
    * Benchmarked Systems
        * [SWI-Prolog](swipl.html#tcff)
        * [xsb](xsb.html#tcff)
        * [YAProlog](yap.html#tcff)
    * Tabling needs to be enabled to ensure termination for cyclic input graphs
    * We evaluate `tc(_,_), fail.` to iterate over the whole relationship
* Graph Databases
    * Benchmarked Systems
        * [Apache Jena](jena.html#tcff) (OpenJDK 1.8 (Java 8), we had to increase the JVM's thread stack size to 16MB `JVM_ARGS=-Xss16m}`)
    * SPARQL does not support general recursion. We used SPARQL 1.1 property paths to define the problem.

The instances are generated using our [graphgen tool](https://gitlab.informatik.uni-halle.de/mwenzel/graphgen).

## SQL Formulation

```
WITH RECURSIVE tc(a,b) AS (
  SELECT par.a, par.b from par
  UNION
  SELECT par.a, tc.b from par JOIN tc ON par.b = tc.a
) SELECT Count(*) FROM tc;
```

with the table definition

```
CREATE TEMP TABLE par (
  a INT NOT NULL, b INT NOT NULL,
  CONSTRAINT par_pk PRIMARY KEY (a, b)
) WITHOUT ROWID;
CREATE INDEX par_fb ON par (b);
```

## SPARQL Formulation

```
SELECT (count(*) as ?resultcount) WHERE {?a :par+ ?b}
```

## CYPHER Formulation

```
MATCH (a)-[*]->(b)
RETURN DISTINCT a,b;
```
