# tcff

We've added an index on the second column of the `par` relation.

```sql
-- tcff.sql.[innodb/memory].tbl
CREATE DATABASE IF NOT EXISTS tc;
use tc;

SET max_heap_table_size = 1024*1024*1024*4; -- only for memory

DROP TABLE IF EXISTS par;
CREATE TABLE par (
  a INT NOT NULL,
  b INT NOT NULL,
  CONSTRAINT par_pk PRIMARY KEY (a, b)
)
ENGINE = Memory; -- or Innodb
CREATE INDEX par_fb ON par (b); --BTREE or HASH for MEMORY

LOAD DATA LOCAL INFILE '{instance}'
INTO TABLE par
COLUMNS TERMINATED BY ', ';
```
```sql
-- tcff.sql
WITH RECURSIVE tc(a,b) AS (
  SELECT par.a, par.b from par
  UNION
  SELECT par.a, tc.b from par JOIN tc ON par.b = tc.a
) SELECT Count(*) FROM tc;
```

```sql
-- tcff.sql.drop.tbl
use tc;
DROP TABLE par;
```

Launch: `cat tcff.sql.[innodb/memory].tbl tcff.sql tcff.sql.drop.tbl | mysql --verbose --user=root -B`

<div id="tcffvis"></div>
<script>make_scatter('tcffvis', 'tsv/tcff_maria_cost.tsv');</script>
