# tcff

Using CYPHER's variable length paths we can formulate loading the data and executing
the query as such:

    //tcff.qry
    MATCH (n)
    DETACH DELETE n;

    LOAD CSV FROM 'file://INSTANCE' AS line
    MERGE (a:Node {n: toInteger(line[0])})
    MERGE (b:Node {n: toInteger(trim(line[1]))})
    CREATE (a)-[:PAR]->(b);

    MATCH (a)-[*]->(b)
    RETURN COUNT(DISTINCT [a,b]);

Launch: `(sed \'s!INSTANCE!{instance}!g\' tcff.qry) | ./cypher-shell -u neo4j`

## Other Formulations

There are different ways to formulate this query that are faster or slower depending
on the specific layout of the graph. The version above is the most general one.

### Early Selection

This query uses a cross-product of all nodes and filters out the pairs that are not connected.

    MATCH (a), (b)
    WHERE (a)-[*]->(b)
    RETURN COUNT(*);


### Using ShortestPath

One can use the `shortestPath` [method](https://neo4j.com/docs/cypher-manual/current/execution-plans/shortestpath-planning/) that does a breadth-first-search from both
nodes to find a shortest path between both nodes.
This does not work if the nodes are the same (and fails with the incorrect settings)
and is slow if the nodes are not connected.
Then each node has to be checked for a connection to itself.


    MATCH shortestPath((a)-[*]->(b))
    RETURN COUNT([a,b]) AS ret
    UNION
    MATCH (a)
    WHERE (a)-[*]->(a)
    RETURN COUNT(*) AS ret;

This query depends on the following settings:
`cypher.forbid_shortestpath_common_nodes=false` and `cypher.forbid_exhaustive_shortestpath=true`.
